@@ -219,6 +219,10 @@ void EDA_BASE_FRAME::windowClosing( wxCloseEvent& event )
     if( canCloseWindow( event ) )
     {
         m_isClosing = true;
+
+        if( m_infoBar )
+            m_infoBar->Dismiss();
+
         APP_SETTINGS_BASE* cfg = config();
 
         if( cfg )
@@ -1230,7 +1234,7 @@ bool EDA_BASE_FRAME::IsWritable( const wxFileName& aFileName, bool aVerbose )
 
 void EDA_BASE_FRAME::CheckForAutoSaveFile( const wxFileName& aFileName )
 {
-    if( !IsGUI() )
+    if( !Pgm().IsGUI() )
         return;
 
     wxCHECK_RET( aFileName.IsOk(), wxT( "Invalid file name!" ) );
