@@ -98,9 +98,10 @@ OUTLINE_FONT* OUTLINE_FONT::LoadFont( const wxString& aFontName, bool aBold, boo
     std::unique_ptr<OUTLINE_FONT> font = std::make_unique<OUTLINE_FONT>();
 
     wxString fontFile;
+    int      faceIndex;
     using fc = fontconfig::FONTCONFIG;
 
-    fc::FF_RESULT retval = Fontconfig()->FindFont( aFontName, fontFile, aBold, aItalic );
+    fc::FF_RESULT retval = Fontconfig()->FindFont( aFontName, fontFile, faceIndex, aBold, aItalic );
 
     if( retval == fc::FF_RESULT::FF_ERROR )
         return nullptr;
@@ -111,7 +112,7 @@ OUTLINE_FONT* OUTLINE_FONT::LoadFont( const wxString& aFontName, bool aBold, boo
     if( retval == fc::FF_RESULT::FF_MISSING_ITAL || retval == fc::FF_RESULT::FF_MISSING_BOLD_ITAL )
         font->SetFakeItal();
 
-    if( font->loadFace( fontFile ) != 0 )
+    if( font->loadFace( fontFile, faceIndex ) != 0 )
         return nullptr;
 
     font->m_fontName = aFontName;       // Keep asked-for name, even if we substituted.
@@ -121,13 +122,13 @@ OUTLINE_FONT* OUTLINE_FONT::LoadFont( const wxString& aFontName, bool aBold, boo
 }
 
 
-FT_Error OUTLINE_FONT::loadFace( const wxString& aFontFileName )
+FT_Error OUTLINE_FONT::loadFace( const wxString& aFontFileName, int aFaceIndex )
 {
     std::lock_guard<std::mutex> guard( m_freeTypeMutex );
 
     // TODO: check that going from wxString to char* with UTF-8
     // conversion for filename makes sense on any/all platforms
-    FT_Error e = FT_New_Face( m_freeType, aFontFileName.mb_str( wxConvUTF8 ), 0, &m_face );
+    FT_Error e = FT_New_Face( m_freeType, aFontFileName.mb_str( wxConvUTF8 ), aFaceIndex, &m_face );
 
     if( !e )
     {
