@@ -196,7 +196,7 @@ wxString EscapeString( const wxString& aSource, ESCAPE_CONTEXT aContext )
         }
         else if( aContext == CTX_JS_STR )
         {
-            if( c >= 0x7F || c == '\'' || c == '\\' )
+            if( c >= 0x7F || c == '\'' || c == '\\' || c == '(' || c == ')' )
             {
                 unsigned int code = c;
                 char buffer[16];
