@@ -46,7 +46,6 @@ UNIT_BINDER::UNIT_BINDER( EDA_DRAW_FRAME* aParent, wxStaticText* aLabel, wxWindo
 UNIT_BINDER::UNIT_BINDER( UNITS_PROVIDER* aUnitsProvider, wxWindow* aEventSource,
                           wxStaticText* aLabel, wxWindow* aValueCtrl, wxStaticText* aUnitLabel,
                           bool aAllowEval, bool aBindFocusEvent ) :
-        m_eventSource( aEventSource ),
         m_bindFocusEvent( aBindFocusEvent ),
         m_label( aLabel ),
         m_valueCtrl( aValueCtrl ),
@@ -99,10 +98,10 @@ UNIT_BINDER::UNIT_BINDER( UNITS_PROVIDER* aUnitsProvider, wxWindow* aEventSource
                  this );
     }
 
-    if( m_eventSource )
+    if( aEventSource )
     {
-        m_eventSource->Connect( UNITS_CHANGED, wxCommandEventHandler( UNIT_BINDER::onUnitsChanged ),
-                                nullptr, this );
+        aEventSource->Connect( UNITS_CHANGED, wxCommandEventHandler( UNIT_BINDER::onUnitsChanged ),
+                               nullptr, this );
     }
 }
 
@@ -115,12 +114,6 @@ UNIT_BINDER::~UNIT_BINDER()
                     this );
     }
 
-    if( m_eventSource )
-    {
-        m_eventSource->Disconnect( UNITS_CHANGED, wxCommandEventHandler( UNIT_BINDER::onUnitsChanged ),
-                                   nullptr, this );
-    }
-
     if( m_valueCtrl )
     {
         m_valueCtrl->Disconnect( wxEVT_SET_FOCUS, wxFocusEventHandler( UNIT_BINDER::onSetFocus ),
@@ -395,7 +388,7 @@ void UNIT_BINDER::SetValue( const wxString& aValue )
 
         value += EDA_UNIT_UTILS::GetLabel( m_units, m_dataType );
     }
- 
+
     if( textEntry )
         textEntry->SetValue( value );
     else if( staticText )
