@@ -273,7 +273,7 @@ void WX_GRID::DestroyTable( wxGridTableBase* aTable )
 }
 
 
-wxString WX_GRID::GetShownColumns()
+wxString WX_GRID::GetShownColumnsAsString()
 {
     wxString shownColumns;
 
@@ -292,6 +292,17 @@ wxString WX_GRID::GetShownColumns()
 }
 
 
+std::bitset<64> WX_GRID::GetShownColumns()
+{
+    std::bitset<64> shownColumns;
+
+    for( int ii = 0; ii < GetNumberCols(); ++ii )
+        shownColumns[ii] = IsColShown( ii );
+
+    return shownColumns;
+}
+
+
 void WX_GRID::ShowHideColumns( const wxString& shownColumns )
 {
     for( int i = 0; i < GetNumberCols(); ++i )
@@ -310,6 +321,18 @@ void WX_GRID::ShowHideColumns( const wxString& shownColumns )
 }
 
 
+void WX_GRID::ShowHideColumns( const std::bitset<64>& aShownColumns )
+{
+    for( int ii = 0; ii < GetNumberCols(); ++ ii )
+    {
+        if( aShownColumns[ii] )
+            ShowCol( ii );
+        else
+            HideCol( ii );
+    }
+}
+
+
 void WX_GRID::DrawCornerLabel( wxDC& dc )
 {
     if( m_nativeColumnLabels )
