@@ -118,13 +118,10 @@ DIALOG_LABEL_PROPERTIES::DIALOG_LABEL_PROPERTIES( SCH_EDIT_FRAME* aParent, SCH_L
     m_grid->SetSelectionMode( wxGrid::wxGridSelectRows );
 
     // Show/hide columns according to user's preference
-    auto cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() );
-    wxASSERT( cfg );
-
-    if( cfg )
+    if( EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() ) )
     {
-        m_shownColumns = cfg->m_Appearance.edit_label_visible_columns;
-        m_grid->ShowHideColumns( m_shownColumns );
+        m_grid->ShowHideColumns( cfg->m_Appearance.edit_label_visible_columns );
+        m_shownColumns = m_grid->GetShownColumns();
     }
 
     // Configure button logos
@@ -221,19 +218,19 @@ DIALOG_LABEL_PROPERTIES::DIALOG_LABEL_PROPERTIES( SCH_EDIT_FRAME* aParent, SCH_L
     // Now all widgets have the size fixed, call FinishDialogSettings
     finishDialogSettings();
 
-    if( cfg && cfg->m_Appearance.edit_label_width > 0 && cfg->m_Appearance.edit_label_height > 0 )
-        SetSize( cfg->m_Appearance.edit_label_width, cfg->m_Appearance.edit_label_height );
+    if( EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() ) )
+    {
+        if( cfg->m_Appearance.edit_label_width > 0 && cfg->m_Appearance.edit_label_height > 0 )
+            SetSize( cfg->m_Appearance.edit_label_width, cfg->m_Appearance.edit_label_height );
+    }
 }
 
 
 DIALOG_LABEL_PROPERTIES::~DIALOG_LABEL_PROPERTIES()
 {
-    EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() );
-    wxASSERT( cfg );
-
-    if( cfg )
+    if( EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() ) )
     {
-        cfg->m_Appearance.edit_label_visible_columns = m_grid->GetShownColumns();
+        cfg->m_Appearance.edit_label_visible_columns = m_grid->GetShownColumnsAsString();
         cfg->m_Appearance.edit_label_width = GetSize().x;
         cfg->m_Appearance.edit_label_height = GetSize().y;
     }
@@ -286,7 +283,11 @@ bool DIALOG_LABEL_PROPERTIES::TransferDataToWindow()
                 for( SCH_ITEM* item : screen->Items().OfType( SCH_SYMBOL_LOCATE_POWER_T ) )
                 {
                     const SCH_SYMBOL* power = static_cast<const SCH_SYMBOL*>( item );
-                    existingLabels.insert( UnescapeString( power->GetValueFieldText( false ) ) );
+
+                    // Ensure the symbol has the Power (i.e. equivalent to a global label
+                    // before adding its value in list
+                    if( power->IsSymbolLikePowerGlobalLabel() )
+                        existingLabels.insert( UnescapeString( power->GetValueFieldText( false ) ) );
                 }
             }
 
@@ -498,6 +499,20 @@ bool DIALOG_LABEL_PROPERTIES::TransferDataFromWindow()
     else
         doAutoplace = true;
 
+    for( int ii = m_fields->GetNumberRows() - 1; ii >= 0; ii-- )
+    {
+        SCH_FIELD&      field = m_fields->at( ii );
+        const wxString& fieldName = field.GetCanonicalName();
+        const wxString& fieldText = field.GetText();
+
+        if( fieldName.IsEmpty() && fieldText.IsEmpty() )
+            m_fields->erase( m_fields->begin() + ii );
+        else if( fieldName == wxT( "Netclass" ) && fieldText.IsEmpty() )
+            m_fields->erase( m_fields->begin() + ii );
+        else if( fieldName.IsEmpty() )
+            field.SetName( _( "untitled" ) );
+    }
+
     m_currentLabel->SetFields( *m_fields );
 
     if( m_shapeSizer->AreAnyItemsShown() )
@@ -758,7 +773,7 @@ void DIALOG_LABEL_PROPERTIES::AdjustGridColumns( int aWidth )
 
 void DIALOG_LABEL_PROPERTIES::OnUpdateUI( wxUpdateUIEvent& event )
 {
-    wxString shownColumns = m_grid->GetShownColumns();
+    std::bitset<64> shownColumns = m_grid->GetShownColumns();
 
     if( shownColumns != m_shownColumns )
     {
