@@ -134,8 +134,8 @@ DIALOG_LIB_SYMBOL_PROPERTIES::~DIALOG_LIB_SYMBOL_PROPERTIES()
 {
     m_lastOpenedPage = m_NoteBook->GetSelection( );
 
-    SYMBOL_EDITOR_SETTINGS* cfg = m_Parent->GetSettings();
-    cfg->m_EditSymbolVisibleColumns = m_grid->GetShownColumns();
+    if( SYMBOL_EDITOR_SETTINGS* cfg = m_Parent->GetSettings() )
+        cfg->m_EditSymbolVisibleColumns = m_grid->GetShownColumnsAsString();
 
     // Prevents crash bug in wxGrid's d'tor
     m_grid->DestroyTable( m_fields );
@@ -302,7 +302,7 @@ bool DIALOG_LIB_SYMBOL_PROPERTIES::Validate()
         LIB_FIELD& field = m_fields->at( ii );
         wxString   fieldName = field.GetName( false );
 
-        if( fieldName.IsEmpty() )
+        if( fieldName.IsEmpty() && !field.GetText().IsEmpty() )
         {
             if( m_NoteBook->GetSelection() != 0 )
                 m_NoteBook->SetSelection( 0 );
@@ -393,6 +393,17 @@ bool DIALOG_LIB_SYMBOL_PROPERTIES::TransferDataFromWindow()
         m_fields->at( ii ).SetId( ii );
     }
 
+    for( int ii = m_fields->GetNumberRows() - 1; ii >= MANDATORY_FIELDS; ii-- )
+    {
+        LIB_FIELD&      field = m_fields->at( ii );
+        const wxString& fieldName = field.GetCanonicalName();
+
+        if( fieldName.IsEmpty() && field.GetText().IsEmpty() )
+            m_fields->erase( m_fields->begin() + ii );
+        else if( fieldName.IsEmpty() )
+            field.SetName( _( "untitled" ) );
+    }
+
     m_libEntry->SetFields( *m_fields );
 
     // Update the parent for inherited symbols
@@ -841,7 +852,7 @@ void DIALOG_LIB_SYMBOL_PROPERTIES::OnUpdateUI( wxUpdateUIEvent& event )
     }
 
     // Handle shown columns changes
-    wxString shownColumns = m_grid->GetShownColumns();
+    std::bitset<64> shownColumns = m_grid->GetShownColumns();
 
     if( shownColumns != m_shownColumns )
     {
