@@ -69,13 +69,10 @@ DIALOG_SHEET_PROPERTIES::DIALOG_SHEET_PROPERTIES( SCH_EDIT_FRAME* aParent, SCH_S
     m_grid->SetSelectionMode( wxGrid::wxGridSelectRows );
 
     // Show/hide columns according to user's preference
-    EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() );
-    wxASSERT( cfg );
-
-    if( cfg )
+    if( EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() ) )
     {
-        m_shownColumns = cfg->m_Appearance.edit_sheet_visible_columns;
-        m_grid->ShowHideColumns( m_shownColumns );
+        m_grid->ShowHideColumns( cfg->m_Appearance.edit_sheet_visible_columns );
+        m_shownColumns = m_grid->GetShownColumns();
     }
 
     if( m_frame->GetColorSettings()->GetOverrideSchItemColors() )
@@ -108,12 +105,9 @@ DIALOG_SHEET_PROPERTIES::DIALOG_SHEET_PROPERTIES( SCH_EDIT_FRAME* aParent, SCH_S
 
 DIALOG_SHEET_PROPERTIES::~DIALOG_SHEET_PROPERTIES()
 {
-    EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() );
-    wxASSERT( cfg );
-
-    if( cfg )
+    if( EESCHEMA_SETTINGS* cfg = dynamic_cast<EESCHEMA_SETTINGS*>( Kiface().KifaceSettings() ) )
     {
-        cfg->m_Appearance.edit_sheet_visible_columns = m_grid->GetShownColumns();
+        cfg->m_Appearance.edit_sheet_visible_columns = m_grid->GetShownColumnsAsString();
         cfg->m_Appearance.edit_sheet_width = GetSize().x;
         cfg->m_Appearance.edit_sheet_height = GetSize().y;
     }
@@ -368,6 +362,17 @@ bool DIALOG_SHEET_PROPERTIES::TransferDataFromWindow()
     if( positioningChanged( m_fields, m_sheet->GetFields() ) )
         m_sheet->ClearFieldsAutoplaced();
 
+    for( int ii = m_fields->GetNumberRows() - 1; ii >= SHEET_MANDATORY_FIELDS; ii-- )
+    {
+        SCH_FIELD&      field = m_fields->at( ii );
+        const wxString& fieldName = field.GetCanonicalName();
+
+        if( fieldName.IsEmpty() && field.GetText().IsEmpty() )
+            m_fields->erase( m_fields->begin() + ii );
+        else if( fieldName.IsEmpty() )
+            field.SetName( _( "untitled" ) );
+    }
+
     m_sheet->SetFields( *m_fields );
 
     m_sheet->SetBorderWidth( m_borderWidth.GetValue() );
@@ -841,7 +846,7 @@ void DIALOG_SHEET_PROPERTIES::AdjustGridColumns()
 
 void DIALOG_SHEET_PROPERTIES::OnUpdateUI( wxUpdateUIEvent& event )
 {
-    wxString shownColumns = m_grid->GetShownColumns();
+    std::bitset<64> shownColumns = m_grid->GetShownColumns();
 
     if( shownColumns != m_shownColumns )
     {
