@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2020 Jon Evans <jon@craftyjon.com>
- * Copyright (C) 2020-2021 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2020-2023 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -20,7 +20,6 @@
 
 #include <regex>
 
-#include <bitmaps.h>
 #include <eeschema_settings.h>
 #include <gal/gal_display_options.h>
 #include <layer_ids.h>
@@ -44,19 +43,19 @@
 #include <drawing_sheet/ds_proxy_view_item.h>
 #include <sch_base_frame.h>
 #include <widgets/color_swatch.h>
+#include <widgets/wx_panel.h>
 #include <wx/msgdlg.h>
 
 
 std::set<int> g_excludedLayers =
         {
+            LAYER_NOTES_BACKGROUND,
             LAYER_DANGLING
         };
 
 
-PANEL_EESCHEMA_COLOR_SETTINGS::PANEL_EESCHEMA_COLOR_SETTINGS( SCH_BASE_FRAME* aFrame,
-                                                              wxWindow* aParent ) :
+PANEL_EESCHEMA_COLOR_SETTINGS::PANEL_EESCHEMA_COLOR_SETTINGS( wxWindow* aParent ) :
         PANEL_COLOR_SETTINGS( aParent ),
-        m_frame( aFrame ),
         m_preview( nullptr ),
         m_page( nullptr ),
         m_titleBlock( nullptr ),
@@ -66,9 +65,6 @@ PANEL_EESCHEMA_COLOR_SETTINGS::PANEL_EESCHEMA_COLOR_SETTINGS( SCH_BASE_FRAME* aF
     m_colorNamespace = "schematic";
 
     SETTINGS_MANAGER&  mgr = Pgm().GetSettingsManager();
-
-    mgr.ReloadColorSettings();
-
     COMMON_SETTINGS*   common_settings = Pgm().GetCommonSettings();
     EESCHEMA_SETTINGS* app_settings = mgr.GetAppSettings<EESCHEMA_SETTINGS>();
     COLOR_SETTINGS*    current = mgr.GetColorSettings( app_settings->m_ColorTheme );
@@ -93,26 +89,10 @@ PANEL_EESCHEMA_COLOR_SETTINGS::PANEL_EESCHEMA_COLOR_SETTINGS( SCH_BASE_FRAME* aF
 
     m_backgroundLayer = LAYER_SCHEMATIC_BACKGROUND;
 
-    createSwatches();
-
     m_galDisplayOptions.ReadConfig( *common_settings, app_settings->m_Window, this );
     m_galDisplayOptions.m_forceDisplayCursor = false;
 
-    auto type = static_cast<EDA_DRAW_PANEL_GAL::GAL_TYPE>( app_settings->m_Graphics.canvas_type );
-
-    m_preview = new SCH_PREVIEW_PANEL( this, wxID_ANY, wxDefaultPosition, wxSize( -1, -1 ),
-                                       m_galDisplayOptions, type );
-    m_preview->SetStealsFocus( false );
-    m_preview->ShowScrollbars( wxSHOW_SB_NEVER, wxSHOW_SB_NEVER );
-    m_preview->GetGAL()->SetAxesEnabled( false );
-
-    m_colorsMainSizer->Add( 10, 0, 0, wxEXPAND, 5 );
-    m_colorsMainSizer->Add( m_preview, 1, wxALL | wxEXPAND, 5 );
-    m_colorsMainSizer->Add( 10, 0, 0, wxEXPAND, 5 );
-
-    createPreviewItems();
-    updatePreview();
-    zoomFitPreview();
+    m_galType = static_cast<EDA_DRAW_PANEL_GAL::GAL_TYPE>( app_settings->m_Graphics.canvas_type );
 }
 
 
@@ -135,8 +115,6 @@ bool PANEL_EESCHEMA_COLOR_SETTINGS::TransferDataFromWindow()
     if( !saveCurrentTheme( true ) )
         return false;
 
-    m_frame->GetCanvas()->GetView()->GetPainter()->GetSettings()->LoadColors( m_currentSettings );
-
     SETTINGS_MANAGER& settingsMgr = Pgm().GetSettingsManager();
     EESCHEMA_SETTINGS* app_settings = settingsMgr.GetAppSettings<EESCHEMA_SETTINGS>();
     app_settings->m_ColorTheme = m_currentSettings->GetFilename();
@@ -209,7 +187,6 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createSwatches()
         layers.push_back( i );
     }
 
-
     std::sort( layers.begin(), layers.end(),
                []( SCH_LAYER_ID a, SCH_LAYER_ID b )
                {
@@ -231,6 +208,23 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createSwatches()
     int min_width = m_colorsGridSizer->GetMinSize().x;
     const int margin = 20;  // A margin around the sizer
     m_colorsListWindow->SetMinSize( wxSize( min_width + margin, -1 ) );
+
+    m_preview = new SCH_PREVIEW_PANEL( m_panel1, wxID_ANY, wxDefaultPosition, wxSize( -1, -1 ),
+                                       m_galDisplayOptions, m_galType );
+    m_preview->SetStealsFocus( false );
+    m_preview->ShowScrollbars( wxSHOW_SB_NEVER, wxSHOW_SB_NEVER );
+    m_preview->GetGAL()->SetAxesEnabled( false );
+
+    KIGFX::SCH_RENDER_SETTINGS* settings = m_preview->GetRenderSettings();
+    settings->m_IsSymbolEditor = true;
+
+    m_colorsMainSizer->Add( m_preview, 1, wxTOP | wxEXPAND, 1 );
+
+    m_colorsMainSizer->Layout();
+
+    createPreviewItems();
+    updatePreview();
+    zoomFitPreview();
 }
 
 
@@ -254,8 +248,10 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
     m_page->SetHeightMils( 5000 );
     m_page->SetWidthMils( 6000 );
 
-    m_drawingSheet = new DS_PROXY_VIEW_ITEM( (int) IU_PER_MILS, m_page, nullptr, m_titleBlock );
+    m_drawingSheet = new DS_PROXY_VIEW_ITEM( (int) schIUScale.IU_PER_MILS, m_page, nullptr,
+                                             m_titleBlock, nullptr );
     m_drawingSheet->SetColorLayer( LAYER_SCHEMATIC_DRAWINGSHEET );
+    m_drawingSheet->SetPageBorderColorLayer( LAYER_SCHEMATIC_PAGE_LIMITS );
     view->Add( m_drawingSheet );
 
     // TODO: It would be nice to parse a schematic file here.
@@ -267,7 +263,7 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
                        m_previewItems.push_back( aItem );
                    };
 
-    std::vector<std::pair<SCH_LAYER_ID, std::pair<wxPoint, wxPoint>>> lines = {
+    std::vector<std::pair<SCH_LAYER_ID, std::pair<VECTOR2I, VECTOR2I>>> lines = {
                 { LAYER_WIRE,  { { 1950, 1500 }, { 2325, 1500 } } },
                 { LAYER_WIRE,  { { 1950, 2600 }, { 2350, 2600 } } },
                 { LAYER_WIRE,  { { 2150, 1700 }, { 2325, 1700 } } },
@@ -284,32 +280,32 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
                 { LAYER_NOTES, { { 2950, 2300 }, { 2350, 2300 } } }
             };
 
-    for( const std::pair<SCH_LAYER_ID, std::pair<wxPoint, wxPoint>>& line : lines )
+    for( const std::pair<SCH_LAYER_ID, std::pair<VECTOR2I, VECTOR2I>>& line : lines )
     {
         SCH_LINE* wire = new SCH_LINE;
         wire->SetLayer( line.first );
         STROKE_PARAMS stroke = wire->GetStroke();
-        stroke.SetWidth( Mils2iu( 6 ) );
+        stroke.SetWidth( schIUScale.MilsToIU( 6 ) );
 
         if( line.first != LAYER_NOTES )
         {
             stroke.SetPlotStyle( PLOT_DASH_TYPE::SOLID );
 
             if( line.first == LAYER_BUS )
-                stroke.SetWidth( Mils2iu( 12 ) );
+                stroke.SetWidth( schIUScale.MilsToIU( 12 ) );
 
         }
 
         wire->SetStroke( stroke );
 
-        wire->SetStartPoint( wxPoint( Mils2iu( line.second.first.x ),
-                                      Mils2iu( line.second.first.y ) ) );
-        wire->SetEndPoint( wxPoint( Mils2iu( line.second.second.x ),
-                                    Mils2iu( line.second.second.y ) ) );
+        wire->SetStartPoint( VECTOR2I( schIUScale.MilsToIU( line.second.first.x ),
+                                       schIUScale.MilsToIU( line.second.first.y ) ) );
+        wire->SetEndPoint( VECTOR2I( schIUScale.MilsToIU( line.second.second.x ),
+                                     schIUScale.MilsToIU( line.second.second.y ) ) );
         addItem( wire );
     }
 
-#define MILS_POINT( x, y ) wxPoint( Mils2iu( x ), Mils2iu( y ) )
+#define MILS_POINT( x, y ) VECTOR2I( schIUScale.MilsToIU( x ), schIUScale.MilsToIU( y ) )
 
     SCH_NO_CONNECT* nc = new SCH_NO_CONNECT;
     nc->SetPosition( MILS_POINT( 2525, 1300 ) );
@@ -324,26 +320,26 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
     addItem( e2 );
 
     SCH_TEXT* t1 = new SCH_TEXT( MILS_POINT( 2850, 2250 ), wxT( "PLAIN TEXT" ) );
-    t1->SetLabelSpinStyle( LABEL_SPIN_STYLE::SPIN::LEFT );
+    t1->SetTextSpinStyle( TEXT_SPIN_STYLE::SPIN::LEFT );
     addItem( t1 );
 
     SCH_LABEL* t2 = new SCH_LABEL( MILS_POINT( 1975, 1500 ), wxT( "LABEL_{0}" ) );
-    t2->SetLabelSpinStyle( LABEL_SPIN_STYLE::SPIN::RIGHT );
+    t2->SetTextSpinStyle( TEXT_SPIN_STYLE::SPIN::RIGHT );
     t2->SetIsDangling( false );
     addItem( t2 );
 
     SCH_LABEL* t3 = new SCH_LABEL( MILS_POINT( 1975, 2600 ), wxT( "LABEL_{1}" ) );
-    t3->SetLabelSpinStyle( LABEL_SPIN_STYLE::SPIN::RIGHT );
+    t3->SetTextSpinStyle( TEXT_SPIN_STYLE::SPIN::RIGHT );
     t3->SetIsDangling( false );
     addItem( t3 );
 
     SCH_GLOBALLABEL* t4 = new SCH_GLOBALLABEL( MILS_POINT( 1750, 1400 ), wxT( "GLOBAL[0..3]" ) );
-    t4->SetLabelSpinStyle( LABEL_SPIN_STYLE::SPIN::LEFT );
+    t4->SetTextSpinStyle( TEXT_SPIN_STYLE::SPIN::LEFT );
     t4->SetIsDangling( false );
     addItem( t4 );
 
     SCH_HIERLABEL* t5 = new SCH_HIERLABEL( MILS_POINT( 3250, 1600 ), wxT( "HIER_LABEL" ) );
-    t5->SetLabelSpinStyle( LABEL_SPIN_STYLE::SPIN::RIGHT );
+    t5->SetTextSpinStyle( TEXT_SPIN_STYLE::SPIN::RIGHT );
     t5->SetIsDangling( false );
     addItem( t5 );
 
@@ -354,25 +350,25 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
 
     {
         auto mapLibItemPosition =
-                []( const wxPoint& aLibPosition ) -> wxPoint
+                []( const VECTOR2I& aLibPosition ) -> VECTOR2I
                 {
-                    return wxPoint( aLibPosition.x, -aLibPosition.y );
+                    return VECTOR2I( aLibPosition.x, -aLibPosition.y );
                 };
 
         LIB_SYMBOL* symbol = new LIB_SYMBOL( wxEmptyString );
-        wxPoint p( 2625, -1600 );
+        VECTOR2I p( 2625, -1600 );
 
         LIB_FIELD& ref = symbol->GetReferenceField();
 
         ref.SetText( wxT( "U1" ) );
         ref.SetPosition( MILS_POINT( p.x + 30, p.y + 260 ) );
-        ref.SetHorizJustify( GR_TEXT_HJUSTIFY_LEFT );
+        ref.SetHorizJustify( GR_TEXT_H_ALIGN_LEFT );
 
         LIB_FIELD& value = symbol->GetValueField();
 
         value.SetText( wxT( "OPA604" ) );
         value.SetPosition( MILS_POINT( p.x + 30, p.y + 180 ) );
-        value.SetHorizJustify( GR_TEXT_HJUSTIFY_LEFT );
+        value.SetHorizJustify( GR_TEXT_H_ALIGN_LEFT );
 
         symbol->SetShowPinNames( true );
         symbol->SetShowPinNumbers( true );
@@ -382,7 +378,7 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
 
         comp_body->SetUnit( 0 );
         comp_body->SetConvert( 0 );
-        comp_body->SetWidth( Mils2iu( 10 ) );
+        comp_body->SetStroke( STROKE_PARAMS( schIUScale.MilsToIU( 10 ), PLOT_DASH_TYPE::SOLID ) );
         comp_body->SetFillMode( FILL_T::FILLED_WITH_BG_BODYCOLOR );
         comp_body->AddPoint( MILS_POINT( p.x - 200, p.y + 200 ) );
         comp_body->AddPoint( MILS_POINT( p.x + 200, p.y ) );
@@ -394,7 +390,7 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
         LIB_PIN* pin = new LIB_PIN( symbol );
 
         pin->SetPosition( MILS_POINT( p.x - 300, p.y + 100 ) );
-        pin->SetLength( Mils2iu( 100 ) );
+        pin->SetLength( schIUScale.MilsToIU( 100 ) );
         pin->SetOrientation( PIN_RIGHT );
         pin->SetType( ELECTRICAL_PINTYPE::PT_INPUT );
         pin->SetNumber( wxT( "1" ) );
@@ -406,7 +402,7 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
         pin = new LIB_PIN( symbol );
 
         pin->SetPosition( MILS_POINT( p.x - 300, p.y - 100 ) );
-        pin->SetLength( Mils2iu( 100 ) );
+        pin->SetLength( schIUScale.MilsToIU( 100 ) );
         pin->SetOrientation( PIN_RIGHT );
         pin->SetType( ELECTRICAL_PINTYPE::PT_INPUT );
         pin->SetNumber( wxT( "2" ) );
@@ -418,7 +414,7 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
         pin = new LIB_PIN( symbol );
 
         pin->SetPosition( MILS_POINT( p.x + 300, p.y ) );
-        pin->SetLength( Mils2iu( 100 ) );
+        pin->SetLength( schIUScale.MilsToIU( 100 ) );
         pin->SetOrientation( PIN_LEFT );
         pin->SetType( ELECTRICAL_PINTYPE::PT_OUTPUT );
         pin->SetNumber( wxT( "3" ) );
@@ -430,8 +426,10 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::createPreviewItems()
         addItem( symbol );
     }
 
-    SCH_SHEET* s = new SCH_SHEET( nullptr, MILS_POINT( 4000, 1300 ) );
-    s->SetSize( wxSize( Mils2iu( 800 ), Mils2iu( 1300 ) ) );
+    SCH_SHEET* s = new SCH_SHEET(
+        /* aParent */ nullptr,
+        /* aPosition */ MILS_POINT( 4000, 1300 ),
+        /* aSize */ wxSize( schIUScale.MilsToIU( 800 ), schIUScale.MilsToIU( 1300 ) ) );
     s->GetFields().at( SHEETNAME ).SetText( wxT( "SHEET" ) );
     s->GetFields().at( SHEETFILENAME ).SetText( _( "/path/to/sheet" ) );
     s->AutoplaceFields( nullptr, false );
@@ -495,18 +493,21 @@ void PANEL_EESCHEMA_COLOR_SETTINGS::updatePreview()
 
 void PANEL_EESCHEMA_COLOR_SETTINGS::zoomFitPreview()
 {
-    KIGFX::VIEW* view = m_preview->GetView();
+    if( m_preview )
+    {
+        KIGFX::VIEW* view = m_preview->GetView();
 
-    view->SetScale( 1.0 );
-    VECTOR2D screenSize = view->ToWorld( m_preview->GetClientSize(), false );
+        view->SetScale( 1.0 );
+        VECTOR2D screenSize = view->ToWorld( m_preview->GetClientSize(), false );
 
-    VECTOR2I psize( m_page->GetWidthIU(), m_page->GetHeightIU() );
-    double scale = view->GetScale() / std::max( fabs( psize.x / screenSize.x ),
-                                                fabs( psize.y / screenSize.y ) );
+        VECTOR2I psize( m_page->GetWidthIU( schIUScale.IU_PER_MILS ), m_page->GetHeightIU( schIUScale.IU_PER_MILS ) );
+        double scale = view->GetScale() / std::max( fabs( psize.x / screenSize.x ),
+                                                    fabs( psize.y / screenSize.y ) );
 
-    view->SetScale( scale * m_galDisplayOptions.m_scaleFactor * 0.8 /* margin */ );
-    view->SetCenter( m_drawingSheet->ViewBBox().Centre() );
-    m_preview->ForceRefresh();
+        view->SetScale( scale * m_galDisplayOptions.m_scaleFactor * 0.8 /* margin */ );
+        view->SetCenter( m_drawingSheet->ViewBBox().Centre() );
+        m_preview->ForceRefresh();
+    }
 }
 
 
