@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015 Jean-Pierre Charras, jp.charras at wanadoo.fr
  * Copyright (C) 2011 Wayne Stambaugh <stambaughw@gmail.com>
- * Copyright (C) 1992-2021 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2023 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,9 +23,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
+#include <algorithm>
+#include <numeric>
+
 #include "connection_graph.h"
 #include <common.h>     // for ExpandEnvVarSubstitutions
 #include <erc.h>
+#include <erc_sch_pin_context.h>
 #include <string_utils.h>
 #include <lib_pin.h>
 #include <sch_edit_frame.h>
@@ -33,10 +37,13 @@
 #include <sch_reference_list.h>
 #include <sch_sheet.h>
 #include <sch_sheet_pin.h>
+#include <sch_textbox.h>
+#include <sch_line.h>
 #include <schematic.h>
 #include <drawing_sheet/ds_draw_item.h>
 #include <drawing_sheet/ds_proxy_view_item.h>
 #include <wx/ffile.h>
+#include <sim/sim_lib_mgr.h>
 
 
 /* ERC tests :
@@ -173,12 +180,12 @@ void ERC_TESTER::TestTextVars( DS_PROXY_VIEW_ITEM* aDrawingSheet )
 
     if( aDrawingSheet )
     {
-        wsItems.SetMilsToIUfactor( IU_PER_MILS );
-        wsItems.SetPageNumber( wxT( "1" ) );
+        wsItems.SetMilsToIUfactor( schIUScale.IU_PER_MILS );
+        wsItems.SetPageNumber( wxS( "1" ) );
         wsItems.SetSheetCount( 1 );
-        wsItems.SetFileName( wxT( "dummyFilename" ) );
-        wsItems.SetSheetName( wxT( "dummySheet" ) );
-        wsItems.SetSheetLayer( wxT( "dummyLayer" ) );
+        wsItems.SetFileName( wxS( "dummyFilename" ) );
+        wsItems.SetSheetName( wxS( "dummySheet" ) );
+        wsItems.SetSheetLayer( wxS( "dummyLayer" ) );
         wsItems.SetProject( &m_schematic->Prj() );
         wsItems.BuildDrawItemsList( aDrawingSheet->GetPageInfo(), aDrawingSheet->GetTitleBlock());
     }
@@ -201,7 +208,7 @@ void ERC_TESTER::TestTextVars( DS_PROXY_VIEW_ITEM* aDrawingSheet )
                 {
                     if( unresolved( field.GetShownText() ) )
                     {
-                        wxPoint pos = field.GetPosition() - symbol->GetPosition();
+                        VECTOR2I pos = field.GetPosition() - symbol->GetPosition();
                         pos = symbol->GetTransform().TransformCoordinate( pos );
                         pos += symbol->GetPosition();
 
@@ -256,6 +263,18 @@ void ERC_TESTER::TestTextVars( DS_PROXY_VIEW_ITEM* aDrawingSheet )
                     screen->Append( marker );
                 }
             }
+            else if( SCH_TEXTBOX* textBox = dynamic_cast<SCH_TEXTBOX*>( item ) )
+            {
+                if( textBox->GetShownText().Matches( wxT( "*${*}*" ) ) )
+                {
+                    std::shared_ptr<ERC_ITEM> ercItem =
+                            ERC_ITEM::Create( ERCE_UNRESOLVED_VARIABLE );
+                    ercItem->SetItems( textBox );
+
+                    SCH_MARKER* marker = new SCH_MARKER( ercItem, textBox->GetPosition() );
+                    screen->Append( marker );
+                }
+            }
         }
 
         for( DS_DRAW_ITEM_BASE* item = wsItems.GetFirst(); item; item = wsItems.GetNext() )
@@ -264,11 +283,10 @@ void ERC_TESTER::TestTextVars( DS_PROXY_VIEW_ITEM* aDrawingSheet )
             {
                 if( text->GetShownText().Matches( wxT( "*${*}*" ) ) )
                 {
-                    std::shared_ptr<ERC_ITEM> ercItem =
-                            ERC_ITEM::Create( ERCE_UNRESOLVED_VARIABLE );
-                    ercItem->SetErrorMessage( _( "Unresolved text variable in drawing sheet." ) );
+                    std::shared_ptr<ERC_ITEM> erc = ERC_ITEM::Create( ERCE_UNRESOLVED_VARIABLE );
+                    erc->SetErrorMessage( _( "Unresolved text variable in drawing sheet" ) );
 
-                    SCH_MARKER* marker = new SCH_MARKER( ercItem, text->GetPosition() );
+                    SCH_MARKER* marker = new SCH_MARKER( erc, text->GetPosition() );
                     screen->Append( marker );
                 }
             }
@@ -289,13 +307,19 @@ int ERC_TESTER::TestConflictingBusAliases()
 
     for( SCH_SCREEN* screen = screens.GetFirst(); screen != nullptr; screen = screens.GetNext() )
     {
-        std::unordered_set< std::shared_ptr<BUS_ALIAS> > screen_aliases = screen->GetBusAliases();
+        const std::set< std::shared_ptr<BUS_ALIAS> > screen_aliases = screen->GetBusAliases();
 
         for( const std::shared_ptr<BUS_ALIAS>& alias : screen_aliases )
         {
+            std::vector<wxString> aliasMembers = alias->Members();
+            std::sort( aliasMembers.begin(), aliasMembers.end() );
+
             for( const std::shared_ptr<BUS_ALIAS>& test : aliases )
             {
-                if( alias->GetName() == test->GetName() && alias->Members() != test->Members() )
+                std::vector<wxString> testMembers = test->Members();
+                std::sort( testMembers.begin(), testMembers.end() );
+
+                if( alias->GetName() == test->GetName() && aliasMembers != testMembers )
                 {
                     msg.Printf( _( "Bus alias %s has conflicting definitions on %s and %s" ),
                                 alias->GetName(),
@@ -325,7 +349,6 @@ int ERC_TESTER::TestMultiunitFootprints()
     SCH_SHEET_LIST sheets = m_schematic->GetSheets();
 
     int errors = 0;
-    std::map<wxString, LIB_ID> footprints;
     SCH_MULTI_UNIT_REFERENCE_MAP refMap;
     sheets.GetMultiUnitSymbols( refMap, true );
 
@@ -386,13 +409,153 @@ int ERC_TESTER::TestMultiunitFootprints()
 }
 
 
+int ERC_TESTER::TestMissingUnits()
+{
+    ERC_SETTINGS&  settings = m_schematic->ErcSettings();
+    SCH_SHEET_LIST sheets = m_schematic->GetSheets();
+
+    int errors = 0;
+    SCH_MULTI_UNIT_REFERENCE_MAP refMap;
+    sheets.GetMultiUnitSymbols( refMap, true );
+
+    for( std::pair<const wxString, SCH_REFERENCE_LIST>& symbol : refMap )
+    {
+        SCH_REFERENCE_LIST& refList = symbol.second;
+
+        wxCHECK2( refList.GetCount(), continue );
+
+        // Reference unit
+        SCH_REFERENCE& base_ref = refList.GetItem( 0 );
+        SCH_SYMBOL* unit = base_ref.GetSymbol();
+        LIB_SYMBOL* libSymbol = base_ref.GetLibPart();
+
+        if( static_cast<ssize_t>( refList.GetCount() ) == libSymbol->GetUnitCount() )
+            continue;
+
+        std::set<int> lib_units;
+        std::set<int> instance_units;
+        std::set<int> missing_units;
+
+        auto report_missing = [&]( std::set<int>& aMissingUnits, wxString aErrorMsg, int aErrorCode )
+        {
+            wxString msg;
+            wxString missing_pin_units = wxT( "[ " );
+            int ii = 0;
+
+            for( int missing_unit : aMissingUnits )
+            {
+                if( ii++ == 3 )
+                {
+                    missing_pin_units += wxT( "....." );
+                    break;
+                }
+
+                missing_pin_units += libSymbol->GetUnitDisplayName( missing_unit ) + ", " ;
+            }
+
+            missing_pin_units.Truncate( missing_pin_units.length() - 2 );
+            missing_pin_units += wxT( " ]" );
+
+            msg.Printf( aErrorMsg, symbol.first, missing_pin_units );
+
+            std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( aErrorCode );
+            ercItem->SetErrorMessage( msg );
+            ercItem->SetItems( unit );
+
+            SCH_MARKER* marker = new SCH_MARKER( ercItem, unit->GetPosition() );
+            base_ref.GetSheetPath().LastScreen()->Append( marker );
+
+            ++errors;
+        };
+
+        for( int ii = 1; ii <= libSymbol->GetUnitCount(); ++ii )
+            lib_units.insert( lib_units.end(), ii );
+
+        for( size_t ii = 0; ii < refList.GetCount(); ++ii )
+            instance_units.insert( instance_units.end(), refList.GetItem( ii ).GetUnit() );
+
+        std::set_difference( lib_units.begin(), lib_units.end(),
+                             instance_units.begin(), instance_units.end(),
+                             std::inserter( missing_units, missing_units.begin() ) );
+
+        if( !missing_units.empty() && settings.IsTestEnabled( ERCE_MISSING_UNIT ) )
+        {
+            report_missing( missing_units, _( "Symbol %s has unplaced units %s" ),
+                    ERCE_MISSING_UNIT );
+        }
+
+        std::set<int> missing_power;
+        std::set<int> missing_input;
+        std::set<int> missing_bidi;
+
+        for( int missing_unit : missing_units )
+        {
+            LIB_PINS pins;
+            int convert = 0;
+
+            for( size_t ii = 0; ii < refList.GetCount(); ++ii )
+            {
+                if( refList.GetItem( ii ).GetUnit() == missing_unit )
+                {
+                    convert = refList.GetItem( ii ).GetSymbol()->GetConvert();
+                    break;
+                }
+            }
+
+            libSymbol->GetPins( pins, missing_unit, convert );
+
+            for( auto pin : pins )
+            {
+                switch( pin->GetType() )
+                {
+                case ELECTRICAL_PINTYPE::PT_POWER_IN:
+                    missing_power.insert( missing_unit );
+                    break;
+
+                case ELECTRICAL_PINTYPE::PT_BIDI:
+                    missing_bidi.insert( missing_unit );
+                    break;
+
+                case ELECTRICAL_PINTYPE::PT_INPUT:
+                    missing_input.insert( missing_unit );
+                    break;
+
+                default:
+                    break;
+                }
+            }
+        }
+
+        if( !missing_power.empty() && settings.IsTestEnabled( ERCE_MISSING_POWER_INPUT_PIN ) )
+        {
+            report_missing( missing_power, _( "Symbol %s has input power pins in units %s that are not placed." ),
+                     ERCE_MISSING_POWER_INPUT_PIN );
+        }
+
+        if( !missing_input.empty() && settings.IsTestEnabled( ERCE_MISSING_INPUT_PIN ) )
+        {
+           report_missing( missing_input, _( "Symbol %s has input pins in units %s that are not placed." ),
+                   ERCE_MISSING_INPUT_PIN );
+        }
+
+        if( !missing_bidi.empty() && settings.IsTestEnabled( ERCE_MISSING_BIDI_PIN ) )
+        {
+            report_missing( missing_bidi, _( "Symbol %s has bidirectional pins in units %s that are not placed." ),
+                    ERCE_MISSING_BIDI_PIN );
+        }
+    }
+
+    return errors;
+}
+
+
 int ERC_TESTER::TestNoConnectPins()
 {
     int err_count = 0;
 
     for( const SCH_SHEET_PATH& sheet : m_schematic->GetSheets() )
     {
-        std::map<wxPoint, std::vector<SCH_PIN*>> pinMap;
+        std::map<VECTOR2I, std::vector<SCH_PIN*>> pinMap;
 
         for( SCH_ITEM* item : sheet.LastScreen()->Items().OfType( SCH_SYMBOL_T ) )
         {
@@ -405,7 +568,7 @@ int ERC_TESTER::TestNoConnectPins()
             }
         }
 
-        for( auto& pair : pinMap )
+        for( const std::pair<const VECTOR2I, std::vector<SCH_PIN*>>& pair : pinMap )
         {
             if( pair.second.size() > 1 )
             {
@@ -416,7 +579,7 @@ int ERC_TESTER::TestNoConnectPins()
                 ercItem->SetItems( pair.second[0], pair.second[1],
                                    pair.second.size() > 2 ? pair.second[2] : nullptr,
                                    pair.second.size() > 3 ? pair.second[3] : nullptr );
-                ercItem->SetErrorMessage( _( "Pins with \"no connection\" type are connected" ) );
+                ercItem->SetErrorMessage( _( "Pins with 'no connection' type are connected" ) );
 
                 SCH_MARKER* marker = new SCH_MARKER( ercItem, pair.first );
                 sheet.LastScreen()->Append( marker );
@@ -435,59 +598,61 @@ int ERC_TESTER::TestPinToPin()
 
     int errors = 0;
 
-    for( const std::pair<NET_NAME_CODE, std::vector<CONNECTION_SUBGRAPH*>> net : nets )
+    for( const std::pair<NET_NAME_CODE_CACHE_KEY, std::vector<CONNECTION_SUBGRAPH*>> net : nets )
     {
-        std::vector<SCH_PIN*> pins;
+        std::vector<ERC_SCH_PIN_CONTEXT>           pins;
         std::unordered_map<EDA_ITEM*, SCH_SCREEN*> pinToScreenMap;
+        bool has_noconnect = false;
 
         for( CONNECTION_SUBGRAPH* subgraph: net.second )
         {
+            if( subgraph->m_no_connect )
+                has_noconnect = true;
+
             for( EDA_ITEM* item : subgraph->m_items )
             {
                 if( item->Type() == SCH_PIN_T )
                 {
-                    pins.emplace_back( static_cast<SCH_PIN*>( item ) );
+                    pins.emplace_back( static_cast<SCH_PIN*>( item ), subgraph->m_sheet );
                     pinToScreenMap[item] = subgraph->m_sheet.LastScreen();
                 }
             }
         }
 
-        // Single-pin nets are handled elsewhere
-        if( pins.size() < 2 )
-            continue;
+        std::set<std::pair<ERC_SCH_PIN_CONTEXT, ERC_SCH_PIN_CONTEXT>> tested;
 
-        std::set<std::pair<SCH_PIN*, SCH_PIN*>> tested;
-
-        SCH_PIN* needsDriver = nullptr;
-        bool     hasDriver   = false;
+        ERC_SCH_PIN_CONTEXT needsDriver;
+        bool                hasDriver = false;
 
         // We need different drivers for power nets and normal nets.
         // A power net has at least one pin having the ELECTRICAL_PINTYPE::PT_POWER_IN
         // and power nets can be driven only by ELECTRICAL_PINTYPE::PT_POWER_OUT pins
         bool     ispowerNet  = false;
 
-        for( SCH_PIN* refPin : pins )
+        for( ERC_SCH_PIN_CONTEXT& refPin : pins )
         {
-            if( refPin->GetType() == ELECTRICAL_PINTYPE::PT_POWER_IN )
+            if( refPin.Pin()->GetType() == ELECTRICAL_PINTYPE::PT_POWER_IN )
             {
                 ispowerNet = true;
                 break;
             }
         }
 
-        for( SCH_PIN* refPin : pins )
+        for( ERC_SCH_PIN_CONTEXT& refPin : pins )
         {
-            ELECTRICAL_PINTYPE refType = refPin->GetType();
+            ELECTRICAL_PINTYPE refType = refPin.Pin()->GetType();
 
             if( DrivenPinTypes.count( refType ) )
             {
                 // needsDriver will be the pin shown in the error report eventually, so try to
                 // upgrade to a "better" pin if possible: something visible and only a power symbol
                 // if this net needs a power driver
-                if( !needsDriver ||
-                    ( !needsDriver->IsVisible() && refPin->IsVisible() ) ||
-                    ( ispowerNet != ( needsDriver->GetType() == ELECTRICAL_PINTYPE::PT_POWER_IN ) &&
-                      ispowerNet == ( refType == ELECTRICAL_PINTYPE::PT_POWER_IN ) ) )
+                if( !needsDriver.Pin()
+                    || ( !needsDriver.Pin()->IsVisible() && refPin.Pin()->IsVisible() )
+                    || ( ispowerNet
+                                 != ( needsDriver.Pin()->GetType()
+                                      == ELECTRICAL_PINTYPE::PT_POWER_IN )
+                         && ispowerNet == ( refType == ELECTRICAL_PINTYPE::PT_POWER_IN ) ) )
                 {
                     needsDriver = refPin;
                 }
@@ -498,21 +663,34 @@ int ERC_TESTER::TestPinToPin()
             else
                 hasDriver |= ( DrivingPinTypes.count( refType ) != 0 );
 
-            for( SCH_PIN* testPin : pins )
+            for( ERC_SCH_PIN_CONTEXT& testPin : pins )
             {
                 if( testPin == refPin )
                     continue;
 
-                std::pair<SCH_PIN*, SCH_PIN*> pair1 = std::make_pair( refPin, testPin );
-                std::pair<SCH_PIN*, SCH_PIN*> pair2 = std::make_pair( testPin, refPin );
+                ERC_SCH_PIN_CONTEXT first_pin = refPin;
+                ERC_SCH_PIN_CONTEXT second_pin = testPin;
 
-                if( tested.count( pair1 ) || tested.count( pair2 ) )
+                if( second_pin < first_pin )
+                    std::swap( first_pin, second_pin );
+
+                std::pair<ERC_SCH_PIN_CONTEXT, ERC_SCH_PIN_CONTEXT> pair =
+                        std::make_pair( first_pin, second_pin );
+
+                if( auto [ins_pin, inserted ] = tested.insert( pair ); !inserted )
                     continue;
 
-                tested.insert( pair1 );
-                tested.insert( pair2 );
+                // Multiple pins in the same symbol that share a type,
+                // name and position are considered
+                // "stacked" and shouldn't trigger ERC errors
+                if( refPin.Pin()->GetParent() == testPin.Pin()->GetParent()
+                    && refPin.Pin()->GetPosition() == testPin.Pin()->GetPosition()
+                    && refPin.Pin()->GetName() == testPin.Pin()->GetName()
+                    && refPin.Pin()->GetType() == testPin.Pin()->GetType()
+                    && refPin.Sheet() == testPin.Sheet() )
+                    continue;
 
-                ELECTRICAL_PINTYPE testType = testPin->GetType();
+                ELECTRICAL_PINTYPE testType = testPin.Pin()->GetType();
 
                 if( ispowerNet )
                     hasDriver |= ( DrivingPowerPinTypes.count( testType ) != 0 );
@@ -526,23 +704,24 @@ int ERC_TESTER::TestPinToPin()
                     std::shared_ptr<ERC_ITEM> ercItem =
                             ERC_ITEM::Create( erc == PIN_ERROR::WARNING ? ERCE_PIN_TO_PIN_WARNING :
                                                                           ERCE_PIN_TO_PIN_ERROR );
-                    ercItem->SetItems( refPin, testPin );
-                    ercItem->SetIsSheetSpecific();
+                    ercItem->SetItems( refPin.Pin(), testPin.Pin() );
+                    ercItem->SetSheetSpecificPath( refPin.Sheet() );
+                    ercItem->SetItemsSheetPaths( refPin.Sheet(), testPin.Sheet() );
 
                     ercItem->SetErrorMessage(
                             wxString::Format( _( "Pins of type %s and %s are connected" ),
                                               ElectricalPinTypeGetText( refType ),
                                               ElectricalPinTypeGetText( testType ) ) );
 
-                    SCH_MARKER* marker = new SCH_MARKER( ercItem,
-                                                         refPin->GetTransformedPosition() );
-                    pinToScreenMap[refPin]->Append( marker );
+                    SCH_MARKER* marker =
+                            new SCH_MARKER( ercItem, refPin.Pin()->GetTransformedPosition() );
+                    pinToScreenMap[refPin.Pin()]->Append( marker );
                     errors++;
                 }
             }
         }
 
-        if( needsDriver && !hasDriver )
+        if( needsDriver.Pin() && !hasDriver && !has_noconnect )
         {
             int err_code = ispowerNet ? ERCE_POWERPIN_NOT_DRIVEN : ERCE_PIN_NOT_DRIVEN;
 
@@ -550,11 +729,11 @@ int ERC_TESTER::TestPinToPin()
             {
                 std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( err_code );
 
-                ercItem->SetItems( needsDriver );
+                ercItem->SetItems( needsDriver.Pin() );
 
-                SCH_MARKER* marker = new SCH_MARKER( ercItem,
-                                                     needsDriver->GetTransformedPosition() );
-                pinToScreenMap[needsDriver]->Append( marker );
+                SCH_MARKER* marker =
+                        new SCH_MARKER( ercItem, needsDriver.Pin()->GetTransformedPosition() );
+                pinToScreenMap[needsDriver.Pin()]->Append( marker );
                 errors++;
             }
         }
@@ -572,10 +751,9 @@ int ERC_TESTER::TestMultUnitPinConflicts()
 
     std::unordered_map<wxString, std::pair<wxString, SCH_PIN*>> pinToNetMap;
 
-    for( const std::pair<NET_NAME_CODE, std::vector<CONNECTION_SUBGRAPH*>> net : nets )
+    for( const std::pair<NET_NAME_CODE_CACHE_KEY, std::vector<CONNECTION_SUBGRAPH*>> net : nets )
     {
-        const wxString& netName = net.first.first;
-        std::vector<SCH_PIN*> pins;
+        const wxString& netName = net.first.Name;
 
         for( CONNECTION_SUBGRAPH* subgraph : net.second )
         {
@@ -589,7 +767,7 @@ int ERC_TESTER::TestMultUnitPinConflicts()
                         continue;
 
                     wxString name = pin->GetParentSymbol()->GetRef( &subgraph->m_sheet ) +
-                                      + wxT( ":" ) + pin->GetShownNumber();
+                                      + ":" + pin->GetShownNumber();
 
                     if( !pinToNetMap.count( name ) )
                     {
@@ -607,7 +785,8 @@ int ERC_TESTER::TestMultUnitPinConflicts()
                                 pinToNetMap[name].first ) );
 
                         ercItem->SetItems( pin, pinToNetMap[name].second );
-                        ercItem->SetIsSheetSpecific();
+                        ercItem->SetSheetSpecificPath( subgraph->m_sheet );
+                        ercItem->SetItemsSheetPaths( subgraph->m_sheet, subgraph->m_sheet );
 
                         SCH_MARKER* marker = new SCH_MARKER( ercItem,
                                                              pin->GetTransformedPosition() );
@@ -629,12 +808,10 @@ int ERC_TESTER::TestSimilarLabels()
 
     int errors = 0;
 
-    std::unordered_map<wxString, SCH_TEXT*> labelMap;
+    std::unordered_map<wxString, SCH_LABEL_BASE*> labelMap;
 
-    for( const std::pair<NET_NAME_CODE, std::vector<CONNECTION_SUBGRAPH*>> net : nets )
+    for( const std::pair<NET_NAME_CODE_CACHE_KEY, std::vector<CONNECTION_SUBGRAPH*>> net : nets )
     {
-        std::vector<SCH_PIN*> pins;
-
         for( CONNECTION_SUBGRAPH* subgraph : net.second )
         {
             for( EDA_ITEM* item : subgraph->m_items )
@@ -645,20 +822,20 @@ int ERC_TESTER::TestSimilarLabels()
                 case SCH_HIER_LABEL_T:
                 case SCH_GLOBAL_LABEL_T:
                 {
-                    SCH_TEXT* text = static_cast<SCH_TEXT*>( item );
+                    SCH_LABEL_BASE* label = static_cast<SCH_LABEL_BASE*>( item );
 
-                    wxString normalized = text->GetShownText().Lower();
+                    wxString normalized = label->GetShownText().Lower();
 
                     if( !labelMap.count( normalized ) )
                     {
-                        labelMap[normalized] = text;
+                        labelMap[normalized] = label;
                     }
-                    else if( labelMap.at( normalized )->GetShownText() != text->GetShownText() )
+                    else if( labelMap.at( normalized )->GetShownText() != label->GetShownText() )
                     {
                         std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_SIMILAR_LABELS );
-                        ercItem->SetItems( text, labelMap.at( normalized ) );
+                        ercItem->SetItems( label, labelMap.at( normalized ) );
 
-                        SCH_MARKER* marker = new SCH_MARKER( ercItem, text->GetPosition() );
+                        SCH_MARKER* marker = new SCH_MARKER( ercItem, label->GetPosition() );
                         subgraph->m_sheet.LastScreen()->Append( marker );
                         errors += 1;
                     }
@@ -693,10 +870,7 @@ int ERC_TESTER::TestLibSymbolIssues()
 
         for( SCH_ITEM* item : screen->Items().OfType( SCH_SYMBOL_T ) )
         {
-            SCH_SYMBOL* symbol = dynamic_cast<SCH_SYMBOL*>( item );
-
-            wxCHECK2( symbol, continue );
-
+            SCH_SYMBOL* symbol = static_cast<SCH_SYMBOL*>( item );
             LIB_SYMBOL* libSymbolInSchematic = symbol->GetLibSymbolRef().get();
 
             wxCHECK2( libSymbolInSchematic, continue );
@@ -708,7 +882,7 @@ int ERC_TESTER::TestLibSymbolIssues()
             {
                 std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_LIB_SYMBOL_ISSUES );
                 ercItem->SetItems( symbol );
-                msg.Printf( _( "The current configuration does not include the library '%s'." ),
+                msg.Printf( _( "The current configuration does not include the library '%s'" ),
                             UnescapeString( libName ) );
                 ercItem->SetErrorMessage( msg );
 
@@ -719,7 +893,7 @@ int ERC_TESTER::TestLibSymbolIssues()
             {
                 std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_LIB_SYMBOL_ISSUES );
                 ercItem->SetItems( symbol );
-                msg.Printf( _( "The library '%s' is not enabled in the current configuration." ),
+                msg.Printf( _( "The library '%s' is not enabled in the current configuration" ),
                             UnescapeString( libName ) );
                 ercItem->SetErrorMessage( msg );
 
@@ -734,7 +908,7 @@ int ERC_TESTER::TestLibSymbolIssues()
             {
                 std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_LIB_SYMBOL_ISSUES );
                 ercItem->SetItems( symbol );
-                msg.Printf( wxT( "Symbol '%s' not found in symbol library '%s'." ),
+                msg.Printf( _( "Symbol '%s' not found in symbol library '%s'" ),
                             UnescapeString( symbolName ),
                             UnescapeString( libName ) );
                 ercItem->SetErrorMessage( msg );
@@ -750,7 +924,7 @@ int ERC_TESTER::TestLibSymbolIssues()
             {
                 std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_LIB_SYMBOL_ISSUES );
                 ercItem->SetItems( symbol );
-                msg.Printf( wxT( "Symbol '%s' has been modified in library '%s'." ),
+                msg.Printf( _( "Symbol '%s' has been modified in library '%s'" ),
                             UnescapeString( symbolName ),
                             UnescapeString( libName ) );
                 ercItem->SetErrorMessage( msg );
@@ -768,3 +942,116 @@ int ERC_TESTER::TestLibSymbolIssues()
 
     return err_count;
 }
+
+
+int ERC_TESTER::TestOffGridEndpoints( int aGridSize )
+{
+    // The minimal grid size allowed to place a pin is 25 mils
+    // the best grid size is 50 mils, but 25 mils is still usable
+    // this is because all symbols are using a 50 mils grid to place pins, and therefore
+    // the wires must be on the 50 mils grid
+    // So raise an error if a pin is not on a 25 mil (or bigger: 50 mil or 100 mil) grid
+    const int min_grid_size = schIUScale.MilsToIU( 25 );
+    const int clamped_grid_size = ( aGridSize < min_grid_size ) ? min_grid_size : aGridSize;
+
+    SCH_SCREENS screens( m_schematic->Root() );
+    int         err_count = 0;
+
+    for( SCH_SCREEN* screen = screens.GetFirst(); screen != nullptr; screen = screens.GetNext() )
+    {
+        std::vector<SCH_MARKER*> markers;
+
+        for( SCH_ITEM* item : screen->Items() )
+        {
+            if( item->Type() == SCH_LINE_T && item->IsConnectable() )
+            {
+                SCH_LINE* line = static_cast<SCH_LINE*>( item );
+
+                if( ( line->GetStartPoint().x % clamped_grid_size ) != 0
+                        || ( line->GetStartPoint().y % clamped_grid_size) != 0 )
+                {
+                    std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_ENDPOINT_OFF_GRID );
+                    ercItem->SetItems( line );
+
+                    markers.emplace_back( new SCH_MARKER( ercItem, line->GetStartPoint() ) );
+                }
+                else if( ( line->GetEndPoint().x % clamped_grid_size ) != 0
+                            || ( line->GetEndPoint().y % clamped_grid_size) != 0 )
+                {
+                    std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_ENDPOINT_OFF_GRID );
+                    ercItem->SetItems( line );
+
+                    markers.emplace_back( new SCH_MARKER( ercItem, line->GetEndPoint() ) );
+                }
+            }
+            else if( item->Type() == SCH_SYMBOL_T )
+            {
+                SCH_SYMBOL* symbol = static_cast<SCH_SYMBOL*>( item );
+
+                for( SCH_PIN* pin : symbol->GetPins( nullptr ) )
+                {
+                    VECTOR2I pinPos = pin->GetTransformedPosition();
+
+                    if( ( pinPos.x % clamped_grid_size ) != 0
+                            || ( pinPos.y % clamped_grid_size) != 0 )
+                    {
+                        std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_ENDPOINT_OFF_GRID );
+                        ercItem->SetItems( pin );
+
+                        markers.emplace_back( new SCH_MARKER( ercItem, pinPos ) );
+                        break;
+                    }
+                }
+            }
+        }
+
+        for( SCH_MARKER* marker : markers )
+        {
+            screen->Append( marker );
+            err_count += 1;
+        }
+    }
+
+    return err_count;
+}
+
+
+int ERC_TESTER::TestSimModelIssues()
+{
+    wxString           msg;
+    WX_STRING_REPORTER reporter( &msg );
+    SCH_SHEET_LIST     sheets = m_schematic->GetSheets();
+    int                err_count = 0;
+    SIM_LIB_MGR        libMgr( &m_schematic->Prj(), &reporter );
+
+    for( SCH_SHEET_PATH& sheet : sheets )
+    {
+        std::vector<SCH_MARKER*> markers;
+
+        for( SCH_ITEM* item : sheet.LastScreen()->Items().OfType( SCH_SYMBOL_T ) )
+        {
+            // Reset for each symbol
+            msg.Clear();
+
+            SCH_SYMBOL*        symbol = static_cast<SCH_SYMBOL*>( item );
+            SIM_LIBRARY::MODEL model = libMgr.CreateModel( &sheet, *symbol );
+
+            if( !msg.IsEmpty() )
+            {
+                std::shared_ptr<ERC_ITEM> ercItem = ERC_ITEM::Create( ERCE_SIMULATION_MODEL );
+                ercItem->SetErrorMessage( msg );
+                ercItem->SetItems( symbol );
+
+                markers.emplace_back( new SCH_MARKER( ercItem, symbol->GetPosition() ) );
+            }
+        }
+
+        for( SCH_MARKER* marker : markers )
+        {
+            sheet.LastScreen()->Append( marker );
+            err_count += 1;
+        }
+    }
+
+    return err_count;
+}
