@@ -647,6 +647,14 @@ SCHEMATIC& SCH_EDIT_FRAME::Schematic() const
 
 
 wxString SCH_EDIT_FRAME::GetScreenDesc() const
+{
+    wxString s = GetCurrentSheet().Last()->GetName();
+
+    return s;
+}
+
+
+wxString SCH_EDIT_FRAME::GetFullScreenDesc() const
 {
     wxString s = GetCurrentSheet().PathHumanReadable();
 
@@ -814,8 +822,6 @@ void SCH_EDIT_FRAME::doCloseWindow()
     if( m_toolManager )
         m_toolManager->ShutdownAllTools();
 
-    RecordERCExclusions();
-
     // Close the find dialog and preserve its setting if it is displayed.
     if( m_findReplaceDialog )
     {
@@ -834,9 +840,6 @@ void SCH_EDIT_FRAME::doCloseWindow()
         m_auimgr.Update();
     }
 
-    if( Kiway().Player( FRAME_SIMULATOR, false ) )
-        Prj().GetProjectFile().m_SchematicSettings->m_NgspiceSimulatorSettings->SaveToFile();
-
     SCH_SCREENS screens( Schematic().Root() );
     wxFileName fn;
 
@@ -865,7 +868,7 @@ void SCH_EDIT_FRAME::doCloseWindow()
         UpdateFileHistory( fileName );
 
     // Make sure local settings are persisted
-    SaveProjectSettings();
+    SaveProjectLocalSettings();
 
     Schematic().RootScreen()->Clear();
 
@@ -1823,13 +1826,19 @@ void SCH_EDIT_FRAME::UpdateItem( EDA_ITEM* aItem, bool isAddOrDelete, bool aUpda
 
 void SCH_EDIT_FRAME::DisplayCurrentSheet()
 {
+    wxCHECK( m_toolManager, /* void */ );
+
     m_toolManager->RunAction( ACTIONS::cancelInteractive, true );
     m_toolManager->RunAction( EE_ACTIONS::clearSelection, true );
     SCH_SCREEN* screen = GetCurrentSheet().LastScreen();
 
-    wxASSERT( screen );
+    wxCHECK( screen, /* void */ );
 
-    SetScreen( screen );
+    m_toolManager->RunAction( EE_ACTIONS::clearSelection, true );
+
+    SCH_BASE_FRAME::SetScreen( screen );
+
+    m_toolManager->ResetTools( TOOL_BASE::MODEL_RELOAD );
 
     // update the References
     GetCurrentSheet().UpdateAllScreenReferences();
@@ -1837,6 +1846,8 @@ void SCH_EDIT_FRAME::DisplayCurrentSheet()
 
     EE_SELECTION_TOOL* selectionTool = m_toolManager->GetTool<EE_SELECTION_TOOL>();
 
+    wxCHECK( selectionTool, /* void */ );
+
     auto visit =
             [&]( EDA_ITEM* item )
             {
@@ -1881,6 +1892,9 @@ void SCH_EDIT_FRAME::DisplayCurrentSheet()
     HardRedraw();   // Ensure all items are redrawn (especially the drawing-sheet items)
 
     SCH_EDITOR_CONTROL* editTool = m_toolManager->GetTool<SCH_EDITOR_CONTROL>();
+
+    wxCHECK( editTool, /* void */ );
+
     TOOL_EVENT dummy;
     editTool->UpdateNetHighlighting( dummy );
 
