@@ -114,7 +114,7 @@ public:
     /**
      * Save changes to the project settings to the project (.pro) file.
      */
-    void SaveProjectSettings() override;
+    void SaveProjectLocalSettings() override;
 
     /**
      * Load the KiCad project file (*.pro) settings specific to Eeschema.
@@ -164,6 +164,7 @@ public:
      * Return a human-readable description of the current screen.
      */
     wxString GetScreenDesc() const override;
+    wxString GetFullScreenDesc() const override;
 
     /**
      * Execute a remote command sent by Pcbnew via a socket connection.
@@ -835,6 +836,8 @@ protected:
 
     void onSize( wxSizeEvent& aEvent );
 
+    void saveProjectSettings() override;
+
 private:
     // Called when resizing the Hierarchy Navigator panel
     void OnResizeHierarchyNavigator( wxSizeEvent& aEvent );
