@@ -483,7 +483,7 @@ COLOR4D SCH_PAINTER::getRenderColor( const EDA_ITEM *aItem, int aLayer, bool aDr
         color = color.Darken( 0.5f );
     }
 
-    if( aDimmed )
+    if( aDimmed && !( aItem->IsSelected() && aDrawingShadows ) )
     {
         COLOR4D sheetColour = m_schSettings.GetLayerColor( LAYER_SCHEMATIC_BACKGROUND );
         color.Desaturate();
@@ -2317,20 +2317,19 @@ void SCH_PAINTER::draw( const SCH_SYMBOL* aSymbol, int aLayer )
 
     if( aSymbol->GetDNP() )
     {
-        BOX2I bbox = aSymbol->GetBodyAndPinsBoundingBox();
+        COLOR_SETTINGS* colors = Pgm().GetSettingsManager().GetColorSettings();
+        BOX2I           bbox = aSymbol->GetBodyAndPinsBoundingBox();
+        VECTOR2I        pt1 = bbox.GetOrigin();
+        VECTOR2I        pt2 = bbox.GetEnd();
 
         m_gal->SetIsStroke( true );
         m_gal->SetIsFill( true );
-        COLOR_SETTINGS* colors = Pgm().GetSettingsManager().GetColorSettings();
-
         m_gal->SetStrokeColor( colors->GetColor( LAYER_ERC_ERR ) );
         m_gal->SetFillColor( colors->GetColor( LAYER_ERC_ERR ) );
 
-            m_gal->DrawSegment( bbox.GetOrigin(), bbox.GetEnd(),
-                    3.0 * schIUScale.MilsToIU( DEFAULT_LINE_WIDTH_MILS ) );
-            m_gal->DrawSegment( bbox.GetOrigin() + VECTOR2I( bbox.GetWidth(), 0 ),
-                                bbox.GetOrigin() + VECTOR2I( 0, bbox.GetHeight() ),
-                    3.0 * schIUScale.MilsToIU( DEFAULT_LINE_WIDTH_MILS ) );
+        m_gal->DrawSegment( pt1, pt2, 3.0 * schIUScale.MilsToIU( DEFAULT_LINE_WIDTH_MILS ) );
+        std::swap( pt1.x, pt2.x );
+        m_gal->DrawSegment( pt1, pt2, 3.0 * schIUScale.MilsToIU( DEFAULT_LINE_WIDTH_MILS ) );
     }
 }
 
@@ -2362,9 +2361,6 @@ void SCH_PAINTER::draw( const SCH_FIELD* aField, int aLayer, bool aDimmed )
     if( shownText.IsEmpty() )
         return;
 
-    if( drawingShadows && !eeconfig()->m_Selection.draw_selected_children )
-        return;
-
     // Calculate the text orientation according to the parent orientation.
     EDA_ANGLE orient = aField->GetTextAngle();
 
@@ -2398,6 +2394,16 @@ void SCH_PAINTER::draw( const SCH_FIELD* aField, int aLayer, bool aDimmed )
         bbox.Offset( label->GetSchematicTextOffset( &m_schSettings ) );
     }
 
+    if( m_schSettings.GetDrawBoundingBoxes() )
+    {
+        m_gal->SetIsFill( false );
+        m_gal->SetIsStroke( true );
+        m_gal->SetStrokeColor( aField->IsSelected() ? COLOR4D( 1.0, 0.2, 0.2, 1 )
+                                                    : COLOR4D( 0.2, 0.2, 0.2, 1 ) );
+        m_gal->SetLineWidth( schIUScale.MilsToIU( 3 ) );
+        m_gal->DrawRectangle( bbox.GetOrigin(), bbox.GetEnd() );
+    }
+
     m_gal->SetStrokeColor( color );
     m_gal->SetFillColor( color );
 
