@@ -1095,6 +1095,14 @@ void SCH_SYMBOL::SwapData( SCH_ITEM* aItem )
 
     std::swap( m_lib_id, symbol->m_lib_id );
 
+    m_pins.swap( symbol->m_pins );      // std::vector's swap()
+
+    for( std::unique_ptr<SCH_PIN>& pin : symbol->m_pins )
+        pin->SetParent( symbol );
+
+    for( std::unique_ptr<SCH_PIN>& pin : m_pins )
+        pin->SetParent( this );
+
     LIB_SYMBOL* libSymbol = symbol->m_part.release();
     symbol->m_part = std::move( m_part );
     symbol->UpdatePins();
@@ -2271,3 +2279,22 @@ bool SCH_SYMBOL::IsPointClickableAnchor( const VECTOR2I& aPos ) const
 
     return false;
 }
+
+
+bool SCH_SYMBOL::IsSymbolLikePowerGlobalLabel() const
+{
+    // return true if the symbol is equivalent to a global label:
+    // It is a Power symbol
+    // It has only one pin type Power input
+
+    if( !GetLibSymbolRef() || !GetLibSymbolRef()->IsPower() )
+        return false;
+
+    std::vector<LIB_PIN*> pin_list = GetAllLibPins();
+
+    if( pin_list.size() != 1 )
+        return false;
+
+    return pin_list[0]->GetType() == ELECTRICAL_PINTYPE::PT_POWER_IN;
+}
+
