@@ -361,11 +361,13 @@ SIM_MODEL::SPICE_INFO SIM_MODEL::SpiceInfo( TYPE aType )
 }
 
 
-template TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<SCH_FIELD>& aFields );
-template TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<LIB_FIELD>& aFields );
+template TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<SCH_FIELD>& aFields,
+                                             REPORTER* aReporter );
+template TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<LIB_FIELD>& aFields,
+                                             REPORTER* aReporter );
 
 template <typename T>
-TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<T>& aFields )
+TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<T>& aFields, REPORTER* aReporter )
 {
     std::string deviceTypeFieldValue = GetFieldValue( &aFields, SIM_DEVICE_TYPE_FIELD );
     std::string typeFieldValue = GetFieldValue( &aFields, SIM_TYPE_FIELD );
@@ -392,6 +394,17 @@ TYPE SIM_MODEL::ReadTypeFromFields( const std::vector<T>& aFields )
     if( typeFromLegacyFields != TYPE::NONE )
         return typeFromLegacyFields;
 
+    if( aReporter )
+    {
+        if( aFields.size() > REFERENCE_FIELD )
+        {
+            aReporter->Report( wxString::Format( _( "Error reading simulation model from symbol '%s':\n%s" ),
+                                                 aFields[REFERENCE_FIELD].GetText(),
+                                                 _( "Failed to read simulation model from fields." ) ),
+                               RPT_SEVERITY_ERROR );
+        }
+    }
+
     return TYPE::NONE;
 }
 
@@ -506,36 +519,46 @@ std::unique_ptr<SIM_MODEL> SIM_MODEL::Create( const SIM_MODEL* aBaseModel,
                                               const std::vector<T>& aFields,
                                               REPORTER* aReporter )
 {
-    TYPE type = ReadTypeFromFields( aFields );
+    std::unique_ptr<SIM_MODEL> model;
+    TYPE                       type;
 
-    // If the model has a specified type, it takes priority over the type of its base class.
-    if( type == TYPE::NONE && aBaseModel )
+    if( aBaseModel )
+    {
         type = aBaseModel->GetType();
 
-    std::unique_ptr<SIM_MODEL> model;
+        // No REPORTER here; we're just checking to see if we have an override
+        if( ReadTypeFromFields( aFields, nullptr ) != TYPE::NONE )
+            type = ReadTypeFromFields( aFields, nullptr );
 
-    // A null base model means the model wasn't found in the library, so create a fallback
+        if( dynamic_cast<const SIM_MODEL_SPICE_FALLBACK*>( aBaseModel ) )
+            model = std::make_unique<SIM_MODEL_SPICE_FALLBACK>( type );
+        else if( dynamic_cast< const SIM_MODEL_RAW_SPICE*>( aBaseModel ) )
+            model = std::make_unique<SIM_MODEL_RAW_SPICE>();
+        else
+            model = Create( type );
 
-    if( !aBaseModel || dynamic_cast<const SIM_MODEL_SPICE_FALLBACK*>( aBaseModel ) )
+        model->SetBaseModel( *aBaseModel );
+    }
+    else  // No base model means the model wasn't found in the library, so create a fallback
+    {
+        type = ReadTypeFromFields( aFields, aReporter );
         model = std::make_unique<SIM_MODEL_SPICE_FALLBACK>( type );
-    else if( dynamic_cast< const SIM_MODEL_RAW_SPICE*>( aBaseModel ) )
-        model = std::make_unique<SIM_MODEL_RAW_SPICE>();
-    else
-        model = Create( type );
+    }
 
     try
     {
-        if( aBaseModel )
-            model->SetBaseModel( *aBaseModel );
-
         model->ReadDataFields( &aFields, aPins );
     }
     catch( IO_ERROR& err )
     {
         if( aReporter )
-            aReporter->Report( err.What(), RPT_SEVERITY_ERROR );
-        else
-            DisplayErrorMessage( nullptr, err.What() );
+        {
+            aReporter->Report( wxString::Format( _( "Error reading simulation model from "
+                                                    "symbol '%s':\n%s" ),
+                                                 aFields[REFERENCE_FIELD].GetText(),
+                                                 err.Problem() ),
+                               RPT_SEVERITY_ERROR );
+        }
     }
 
     return model;
@@ -557,7 +580,7 @@ std::unique_ptr<SIM_MODEL> SIM_MODEL::Create( const std::vector<T>& aFields,
                                               const std::vector<LIB_PIN*>& aPins,
                                               bool aResolved, REPORTER* aReporter )
 {
-    TYPE type = ReadTypeFromFields( aFields );
+    TYPE type = ReadTypeFromFields( aFields, aReporter );
     std::unique_ptr<SIM_MODEL> model = SIM_MODEL::Create( type );
 
     try
@@ -589,11 +612,15 @@ std::unique_ptr<SIM_MODEL> SIM_MODEL::Create( const std::vector<T>& aFields,
         }
         catch( const IO_ERROR& err )
         {
-            // We own the pin syntax, so if we can't parse it then there's an error, full stop.
+            // We own the pin syntax, so if we can't parse it then there's an error.
             if( aReporter )
-                aReporter->Report( err.Problem(), RPT_SEVERITY_ERROR );
-            else
-                THROW_IO_ERROR( err.Problem() );
+            {
+                aReporter->Report( wxString::Format( _( "Error reading simulation model from "
+                                                        "symbol '%s':\n%s" ),
+                                                     aFields[REFERENCE_FIELD].GetText(),
+                                                     err.Problem() ),
+                                   RPT_SEVERITY_ERROR );
+            }
         }
     }
 
@@ -726,21 +753,8 @@ void SIM_MODEL::AddParam( const PARAM::INFO& aInfo )
 
 void SIM_MODEL::SetBaseModel( const SIM_MODEL& aBaseModel )
 {
-    auto describe =
-            []( const SIM_MODEL* aModel )
-            {
-                return fmt::format( "{} ({})",
-                                    aModel->GetDeviceInfo().fieldValue,
-                                    aModel->GetTypeInfo().description );
-            };
-
-    if( GetType() != aBaseModel.GetType() )
-    {
-        THROW_IO_ERROR( wxString::Format( _( "Simulation model type must be the same as of its "
-                                             "base class: '%s', but is '%s'" ),
-                                          describe( &aBaseModel ),
-                                          describe( this ) ) );
-    }
+    wxASSERT_MSG( GetType() == aBaseModel.GetType(),
+                  wxS( "Simulation model type must be the same as its base class!" ) );
 
     m_baseModel = &aBaseModel;
 }
@@ -1079,6 +1093,9 @@ bool SIM_MODEL::requiresSpiceModelLine( const SPICE_ITEM& aItem ) const
             continue;
 
         const SIM_MODEL* baseModel = dynamic_cast<const SIM_MODEL*>( m_baseModel );
+
+        wxCHECK( baseModel, false );
+
         std::string      baseValue = baseModel->m_params[ii].value;
 
         if( param.value == baseValue )
@@ -1647,7 +1664,7 @@ void SIM_MODEL::MigrateSimModel( T_symbol& aSymbol, const PROJECT* aProject )
             }
             else
             {
-                for( unsigned ii = 0; ii < pinIndexes.size(); ++ii )
+                for( unsigned ii = 0; ii < pinIndexes.size() && ii < sourcePins.size(); ++ii )
                 {
                     if( ii > 0 )
                         pinMap.Append( wxS( " " ) );
@@ -1673,6 +1690,7 @@ void SIM_MODEL::MigrateSimModel( T_symbol& aSymbol, const PROJECT* aProject )
     wxString spiceDeviceType = spiceDeviceInfo.m_Text.Trim( true ).Trim( false );
     wxString spiceLib = spiceLibInfo.m_Text.Trim( true ).Trim( false );
     wxString spiceModel = spiceModelInfo.m_Text.Trim( true ).Trim( false );
+    wxString modelLineParams;
 
     bool libraryModel = false;
     bool inferredModel = false;
@@ -1685,6 +1703,10 @@ void SIM_MODEL::MigrateSimModel( T_symbol& aSymbol, const PROJECT* aProject )
         SIM_LIB_MGR          libMgr( aProject, &reporter );
         std::vector<T_field> emptyFields;
 
+        // Pull out any following parameters from model name
+        spiceModel = spiceModel.BeforeFirst( ' ', &modelLineParams );
+        spiceModelInfo.m_Text = spiceModel;
+
         SIM_LIBRARY::MODEL model = libMgr.CreateModel( spiceLib, spiceModel.ToStdString(),
                                                        emptyFields, sourcePins );
 
@@ -1734,6 +1756,7 @@ void SIM_MODEL::MigrateSimModel( T_symbol& aSymbol, const PROJECT* aProject )
 
                         if( spiceTypeInfo.m_Text == wxT( "DC" ) && tokenizer.CountTokens() == 1 )
                         {
+                            wxCHECK( valueField, /* void */ );
                             valueField->SetText( tokenizer.GetNextToken() );
                             modelFromValueField = false;
                         }
@@ -1779,9 +1802,23 @@ void SIM_MODEL::MigrateSimModel( T_symbol& aSymbol, const PROJECT* aProject )
         T_field nameField = spiceModelInfo.CreateField( &aSymbol, SIM_NAME_FIELD );
         aSymbol.AddField( nameField );
 
-        // Don't write a paramsField unless we actually have overrides
-        if( !spiceParamsInfo.IsEmpty() )
+        if( !modelLineParams.IsEmpty() )
         {
+            spiceParamsInfo = spiceModelInfo;
+            spiceParamsInfo.m_Pos.x += nameField.GetBoundingBox().GetWidth();
+            spiceParamsInfo.m_Text = modelLineParams;
+
+            BOX2I nameBBox = nameField.GetBoundingBox();
+            int   nameWidth = nameBBox.GetWidth();
+
+            // Add space between model name and additional parameters
+            nameWidth += KiROUND( nameBBox.GetHeight() * 1.25 );
+
+            if( nameField.GetHorizJustify() == GR_TEXT_H_ALIGN_RIGHT )
+                spiceParamsInfo.m_Pos.x -= nameWidth;
+            else
+                spiceParamsInfo.m_Pos.x += nameWidth;
+
             T_field paramsField = spiceParamsInfo.CreateField( &aSymbol, SIM_PARAMS_FIELD );
             aSymbol.AddField( paramsField );
         }
