@@ -384,7 +384,7 @@ public:
 
 
     template <typename T>
-    static TYPE ReadTypeFromFields( const std::vector<T>& aFields );
+    static TYPE ReadTypeFromFields( const std::vector<T>& aFields, REPORTER* aReporter );
 
     template <typename T>
     static TYPE InferTypeFromLegacyFields( const std::vector<T>& aFields );
