@@ -55,7 +55,6 @@ std::vector<std::string> SPICE_GENERATOR_NGSPICE::CurrentNames( const SPICE_ITEM
             return SPICE_GENERATOR::CurrentNames( aItem );
 
         default:
-            wxFAIL_MSG( "Unhandled model device type in SIM_MODEL_NGSPICE" );
             return {};
     }
 }
@@ -68,9 +67,10 @@ SIM_MODEL_NGSPICE::SIM_MODEL_NGSPICE( TYPE aType ) :
 
     for( const SIM_MODEL::PARAM::INFO& paramInfo : modelInfo.instanceParams )
     {
-        // For now, only the geometry parameters.
+        // For now, only the geometry and flags parameters.
         if( paramInfo.category == SIM_MODEL::PARAM::CATEGORY::PRINCIPAL
-            || paramInfo.category == SIM_MODEL::PARAM::CATEGORY::GEOMETRY )
+            || paramInfo.category == SIM_MODEL::PARAM::CATEGORY::GEOMETRY
+            || paramInfo.category == SIM_MODEL::PARAM::CATEGORY::FLAGS )
         {
             AddParam( paramInfo );
         }
@@ -211,6 +211,17 @@ bool SIM_MODEL_NGSPICE::canSilentlyIgnoreParam( const std::string& aParamName )
         }
     }
 
+    if( GetType() == TYPE::NMOS_VDMOS || GetType() == TYPE::PMOS_VDMOS )
+    {
+        // Ignore the purely informative LTspice-specific parameters "Vds", "Ron" and "Qg".
+        if( aParamName == "vds"
+            || aParamName == "ron"
+            || aParamName == "qg" )
+        {
+            return true;
+        }
+    }
+
     return false;
 }
 
