@@ -38,6 +38,7 @@ namespace SIM_MODEL_SERIALIZER_PARSER
 
     template <typename Rule> struct fieldParamValuePairsSelector : std::false_type {};
     template <> struct fieldParamValuePairsSelector<param> : std::true_type {};
+    template <> struct fieldParamValuePairsSelector<flagParam> : std::true_type {};
     template <> struct fieldParamValuePairsSelector<quotedStringContent> : std::true_type {};
     template <> struct fieldParamValuePairsSelector<unquotedString> : std::true_type {};
 
@@ -94,6 +95,9 @@ std::string SIM_MODEL_SERIALIZER::GenerateParams() const
             continue;
         }
 
+        if( m_model.GetBaseModel() && m_model.GetBaseModel()->GetParam( i ).value == param.value )
+            continue;
+
         // If the parameter is an enum and the value is default, don't write anything.
         if( param.info.enumValues.size() >= 1 && param.value == param.info.defaultValue )
             continue;
@@ -235,6 +239,12 @@ bool SIM_MODEL_SERIALIZER::ParseParams( const std::string& aParams )
 
             m_model.SetParamValue( paramName, str, SIM_VALUE_GRAMMAR::NOTATION::SI );
         }
+        else if( node->is_type<SIM_MODEL_SERIALIZER_PARSER::flagParam>() )
+        {
+            std::string token = node->string();
+
+            m_model.SetParamValue( token, "1", SIM_VALUE_GRAMMAR::NOTATION::SI );
+        }
         else
         {
             wxFAIL;
@@ -297,7 +307,10 @@ std::string SIM_MODEL_SERIALIZER::generateParamValuePair( const SIM_MODEL::PARAM
         name = aParam.info.name.substr( 0, aParam.info.name.length() - 1 );
 
     std::string value = aParam.value;
-    
+
+    if( aParam.info.category == SIM_MODEL::PARAM::CATEGORY::FLAGS )
+        return value == "1" ? aParam.info.name : "";
+
     if( value == "" || value.find( ' ' ) != std::string::npos )
         value = fmt::format( "\"{}\"", value );
 
