@@ -291,7 +291,7 @@ void SIM_PLOT_FRAME::SaveSettings( APP_SETTINGS_BASE* aCfg )
             project.m_SchematicSettings->m_NgspiceSimulatorSettings->SaveToFile();
 
         if( m_schematicFrame )
-            m_schematicFrame->SaveProjectSettings();
+            m_schematicFrame->OnModify();
     }
 }
 
@@ -1069,7 +1069,8 @@ bool SIM_PLOT_FRAME::loadWorkbook( const wxString& aPath )
             }
             #endif
 
-            addPlot( name, (SIM_PLOT_TYPE) traceType );
+            if( traceType != SPT_UNKNOWN )
+                addPlot( name, (SIM_PLOT_TYPE) traceType );
         }
     }
 
