@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019 CERN
- * Copyright (C) 2019-2021 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2022 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,20 +23,21 @@
  */
 
 #include <kiway.h>
+#include <pgm_base.h>
 #include <sch_painter.h>
 #include <tool/tool_manager.h>
 #include <tools/ee_actions.h>
 #include <tools/symbol_editor_control.h>
 #include <symbol_edit_frame.h>
-#include <symbol_library_manager.h>
+#include <lib_symbol_library_manager.h>
 #include <symbol_viewer_frame.h>
 #include <symbol_tree_model_adapter.h>
 #include <wildcards_and_files_ext.h>
-#include <wildcards_and_files_ext.h>
 #include <bitmaps/bitmap_types.h>
 #include <confirm.h>
 #include <wx/filedlg.h>
-
+#include "wx/generic/textdlgg.h"
+#include "string_utils.h"
 
 bool SYMBOL_EDITOR_CONTROL::Init()
 {
@@ -81,7 +82,7 @@ bool SYMBOL_EDITOR_CONTROL::Init()
         auto symbolSelectedCondition =
                 [ editFrame ]( const SELECTION& aSel )
                 {
-                    LIB_ID sel = editFrame->GetTreeLIBID();
+                    LIB_ID sel = editFrame->GetTargetLibId();
                     return !sel.GetLibNickname().empty() && !sel.GetLibItemName().empty();
                 };
         auto saveSymbolAsCondition =
@@ -90,6 +91,11 @@ bool SYMBOL_EDITOR_CONTROL::Init()
                     LIB_ID sel = editFrame->GetTargetLibId();
                     return !sel.GetLibNickname().empty() && !sel.GetLibItemName().empty();
                 };
+        auto multiSelectedCondition =
+                [ editFrame ]( const SELECTION& aSel )
+                {
+                    return editFrame->GetTreeSelectionCount() > 1;
+                };
 
         ctxMenu.AddItem( ACTIONS::pinLibrary,            unpinnedLibSelectedCondition );
         ctxMenu.AddItem( ACTIONS::unpinLibrary,          pinnedLibSelectedCondition );
@@ -104,11 +110,12 @@ bool SYMBOL_EDITOR_CONTROL::Init()
         ctxMenu.AddItem( ACTIONS::revert,                symbolSelectedCondition || libInferredCondition );
 
         ctxMenu.AddSeparator();
-        ctxMenu.AddItem( EE_ACTIONS::cutSymbol,          symbolSelectedCondition );
-        ctxMenu.AddItem( EE_ACTIONS::copySymbol,         symbolSelectedCondition );
+        ctxMenu.AddItem( EE_ACTIONS::cutSymbol,          symbolSelectedCondition || multiSelectedCondition );
+        ctxMenu.AddItem( EE_ACTIONS::copySymbol,         symbolSelectedCondition || multiSelectedCondition );
         ctxMenu.AddItem( EE_ACTIONS::pasteSymbol,        libInferredCondition );
         ctxMenu.AddItem( EE_ACTIONS::duplicateSymbol,    symbolSelectedCondition );
-        ctxMenu.AddItem( EE_ACTIONS::deleteSymbol,       symbolSelectedCondition );
+        ctxMenu.AddItem( EE_ACTIONS::renameSymbol,       symbolSelectedCondition );
+        ctxMenu.AddItem( EE_ACTIONS::deleteSymbol,       symbolSelectedCondition || multiSelectedCondition );
 
         ctxMenu.AddSeparator();
         ctxMenu.AddItem( EE_ACTIONS::importSymbol,       libInferredCondition );
@@ -133,6 +140,16 @@ int SYMBOL_EDITOR_CONTROL::AddLibrary( const TOOL_EVENT& aEvent )
 }
 
 
+int SYMBOL_EDITOR_CONTROL::DdAddLibrary( const TOOL_EVENT& aEvent )
+{
+    wxString libFile = *aEvent.Parameter<wxString*>();
+    if( m_frame->IsType( FRAME_SCH_SYMBOL_EDITOR ) )
+        static_cast<SYMBOL_EDIT_FRAME*>( m_frame )->DdAddLibrary( libFile );
+
+    return 0;
+}
+
+
 int SYMBOL_EDITOR_CONTROL::EditSymbol( const TOOL_EVENT& aEvent )
 {
     if( m_frame->IsType( FRAME_SCH_SYMBOL_EDITOR ) )
@@ -231,17 +248,25 @@ int SYMBOL_EDITOR_CONTROL::CutCopyDelete( const TOOL_EVENT& aEvt )
 
         if( aEvt.IsAction( &EE_ACTIONS::cutSymbol ) || aEvt.IsAction( &EE_ACTIONS::deleteSymbol ) )
         {
-            LIB_ID          sel = editFrame->GetTreeLIBID();
-            const wxString& libName = sel.GetLibNickname();
-            wxString        msg;
+            bool hasWritableLibs = false;
+            wxString msg;
 
-            if( editFrame->GetLibManager().IsLibraryReadOnly( libName ) )
+            for( LIB_ID& sel : editFrame->GetSelectedLibIds() )
             {
-                msg.Printf( _( "Symbol library '%s' is not writable." ), libName );
-                m_frame->ShowInfoBarError( msg );
-                return 0;
+                const wxString& libName = sel.GetLibNickname();
+
+                if( editFrame->GetLibManager().IsLibraryReadOnly( libName ) )
+                    msg.Printf( _( "Symbol library '%s' is not writable." ), libName );
+                else
+                    hasWritableLibs = true;
             }
 
+            if( !msg.IsEmpty() )
+                m_frame->ShowInfoBarError( msg );
+
+            if( !hasWritableLibs )
+                return 0;
+
             editFrame->DeleteSymbolFromLibrary();
         }
     }
@@ -285,6 +310,96 @@ int SYMBOL_EDITOR_CONTROL::DuplicateSymbol( const TOOL_EVENT& aEvent )
 }
 
 
+int SYMBOL_EDITOR_CONTROL::RenameSymbol( const TOOL_EVENT& aEvent )
+{
+    if( m_frame->IsType( FRAME_SCH_SYMBOL_EDITOR ) )
+    {
+        SYMBOL_EDIT_FRAME*          editFrame = static_cast<SYMBOL_EDIT_FRAME*>( m_frame );
+        LIB_SYMBOL_LIBRARY_MANAGER& libMgr    = editFrame->GetLibManager();
+
+        LIB_ID   libId = editFrame->GetTreeLIBID();
+        wxString libName = libId.GetLibNickname();
+        wxString symbolName = libId.GetLibItemName();
+        wxString newName = symbolName;
+        bool     done = false;
+
+        if( !libMgr.LibraryExists( libName ) )
+            return 0;
+
+        while( !done )
+        {
+            wxTextEntryDialog dlg( m_frame, _( "New name:" ), _( "Change Symbol Name" ), newName );
+
+            if( dlg.ShowModal() != wxID_OK )
+                return 0;   // canceled by user
+
+            newName = EscapeString( dlg.GetValue(), CTX_LIBID );
+            newName.Trim( true ).Trim( false );
+
+            if( newName.IsEmpty() )
+            {
+                DisplayErrorMessage( editFrame, _( "Symbol name cannot be empty." ) );
+            }
+            else if( libMgr.SymbolExists( newName, libName ) )
+            {
+                DisplayErrorMessage( editFrame, wxString::Format( _( "Symbol name '%s' already "
+                                                                     "in use in library '%s'." ),
+                                                                  UnescapeString( newName ),
+                                                                  libName ) );
+                newName = symbolName;
+            }
+            else
+            {
+                done = true;
+            }
+        }
+
+        wxString    oldName = symbolName;
+        LIB_SYMBOL* libSymbol = nullptr;
+
+        if( editFrame->IsCurrentSymbol( libId ) )
+        {
+            // Update buffered copy
+            libSymbol = libMgr.GetBufferedSymbol( oldName, libName );
+
+            libSymbol->SetName( newName );
+            libSymbol->GetFieldById( VALUE_FIELD )->SetText( newName );
+
+            libMgr.UpdateSymbolAfterRename( libSymbol, newName, libName );
+
+            // Now update canvasy copy
+            libSymbol = editFrame->GetCurSymbol();
+
+            libSymbol->SetName( newName );
+            libSymbol->GetFieldById( VALUE_FIELD )->SetText( newName );
+
+            editFrame->RebuildView();
+            editFrame->OnModify();
+
+            // N.B. The view needs to be rebuilt first as the Symbol Properties change may
+            // invalidate the view pointers by rebuilting the field table
+            editFrame->UpdateMsgPanel();
+        }
+        else
+        {
+            libSymbol = libMgr.GetBufferedSymbol( oldName, libName );
+
+            libSymbol->SetName( newName );
+            libSymbol->GetFieldById( VALUE_FIELD )->SetText( newName );
+
+            libMgr.UpdateSymbolAfterRename( libSymbol, newName, libName );
+            libMgr.SetSymbolModified( newName, libName );
+        }
+
+        wxDataViewItem treeItem = libMgr.GetAdapter()->FindItem( libId );
+        editFrame->UpdateLibraryTree( treeItem, libSymbol );
+        editFrame->FocusOnLibId( LIB_ID( libName, newName ) );
+    }
+
+    return 0;
+}
+
+
 int SYMBOL_EDITOR_CONTROL::OnDeMorgan( const TOOL_EVENT& aEvent )
 {
     int convert = aEvent.IsAction( &EE_ACTIONS::showDeMorganStandard ) ?
@@ -320,6 +435,8 @@ int SYMBOL_EDITOR_CONTROL::PinLibrary( const TOOL_EVENT& aEvent )
 
         if( currentNode && !currentNode->m_Pinned )
         {
+            m_frame->Prj().PinLibrary( currentNode->m_LibId.GetLibNickname(), true );
+
             currentNode->m_Pinned = true;
             editFrame->RegenerateLibraryTree();
         }
@@ -338,6 +455,8 @@ int SYMBOL_EDITOR_CONTROL::UnpinLibrary( const TOOL_EVENT& aEvent )
 
         if( currentNode && currentNode->m_Pinned )
         {
+            m_frame->Prj().UnpinLibrary( currentNode->m_LibId.GetLibNickname(), true );
+
             currentNode->m_Pinned = false;
             editFrame->RegenerateLibraryTree();
         }
@@ -372,6 +491,19 @@ int SYMBOL_EDITOR_CONTROL::ShowElectricalTypes( const TOOL_EVENT& aEvent )
 }
 
 
+int SYMBOL_EDITOR_CONTROL::ShowPinNumbers( const TOOL_EVENT& aEvent )
+{
+    KIGFX::SCH_RENDER_SETTINGS* renderSettings = m_frame->GetRenderSettings();
+    renderSettings->m_ShowPinNumbers = !renderSettings->m_ShowPinNumbers;
+
+    // Update canvas
+    m_frame->GetCanvas()->GetView()->UpdateAllItems( KIGFX::REPAINT );
+    m_frame->GetCanvas()->Refresh();
+
+    return 0;
+}
+
+
 int SYMBOL_EDITOR_CONTROL::ToggleSyncedPinsMode( const TOOL_EVENT& aEvent )
 {
     if( !m_isSymbolEditor )
@@ -398,10 +530,8 @@ int SYMBOL_EDITOR_CONTROL::ExportView( const TOOL_EVENT& aEvent )
         return 0;
     }
 
-    wxString   file_ext = wxT( "png" );
-    wxString   mask = wxT( "*." ) + file_ext;
     wxFileName fn( symbol->GetName() );
-    fn.SetExt( wxT( "png" ) );
+    fn.SetExt( "png" );
 
     wxString projectPath = wxPathOnly( m_frame->Prj().GetProjectFullName() );
 
@@ -438,7 +568,6 @@ int SYMBOL_EDITOR_CONTROL::ExportSymbolAsSVG( const TOOL_EVENT& aEvent )
         return 0;
     }
 
-    wxString   file_ext = SVGFileExtension;
     wxFileName fn( symbol->GetName() );
     fn.SetExt( SVGFileExtension );
 
@@ -453,15 +582,20 @@ int SYMBOL_EDITOR_CONTROL::ExportSymbolAsSVG( const TOOL_EVENT& aEvent )
         PAGE_INFO pageSave = editFrame->GetScreen()->GetPageSettings();
         PAGE_INFO pageTemp = pageSave;
 
-        wxSize symbolSize = symbol->GetUnitBoundingBox( editFrame->GetUnit(),
-                                                        editFrame->GetConvert() ).GetSize();
+        BOX2I symbolBBox = symbol->GetUnitBoundingBox( editFrame->GetUnit(),
+                                                       editFrame->GetConvert(), false );
 
-        // Add a small margin to the plot bounding box
-        pageTemp.SetWidthMils(  int( symbolSize.x * 1.2 ) );
-        pageTemp.SetHeightMils( int( symbolSize.y * 1.2 ) );
+        // Add a small margin (10% of size)to the plot bounding box
+        symbolBBox.Inflate( symbolBBox.GetSize().x * 0.1, symbolBBox.GetSize().y * 0.1 );
+
+        pageTemp.SetWidthMils( schIUScale.IUToMils( symbolBBox.GetSize().x ) );
+        pageTemp.SetHeightMils( schIUScale.IUToMils( symbolBBox.GetSize().y ) );
+
+        // Add an offet to plot the symbol centered on the page.
+        VECTOR2I plot_offset = symbolBBox.GetOrigin();
 
         editFrame->GetScreen()->SetPageSettings( pageTemp );
-        editFrame->SVGPlotSymbol( fullFileName );
+        editFrame->SVGPlotSymbol( fullFileName, -plot_offset );
         editFrame->GetScreen()->SetPageSettings( pageSave );
     }
 
@@ -518,6 +652,11 @@ int SYMBOL_EDITOR_CONTROL::AddSymbolToSchematic( const TOOL_EVENT& aEvent )
             return 0;
         }
 
+        wxWindow* blocking_dialog = schframe->Kiway().GetBlockingDialog();
+
+        if( blocking_dialog )
+            blocking_dialog->Close( true );
+
         wxCHECK( libSymbol->GetLibId().IsValid(), 0 );
 
         SCH_SYMBOL* symbol = new SCH_SYMBOL( *libSymbol, libId, &schframe->GetCurrentSheet(),
@@ -529,7 +668,7 @@ int SYMBOL_EDITOR_CONTROL::AddSymbolToSchematic( const TOOL_EVENT& aEvent )
             symbol->AutoplaceFields( /* aScreen */ nullptr, /* aManual */ false );
 
         schframe->Raise();
-        schframe->GetToolManager()->RunAction( EE_ACTIONS::placeSymbol, true, symbol );
+        schframe->GetToolManager()->RunAction( EE_ACTIONS::placeSymbol, false, symbol );
     }
 
     return 0;
@@ -544,6 +683,8 @@ void SYMBOL_EDITOR_CONTROL::setTransitions()
     Go( &SYMBOL_EDITOR_CONTROL::AddSymbol,             EE_ACTIONS::importSymbol.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::EditSymbol,            EE_ACTIONS::editSymbol.MakeEvent() );
 
+    Go( &SYMBOL_EDITOR_CONTROL::DdAddLibrary,          ACTIONS::ddAddLibrary.MakeEvent() );
+
     Go( &SYMBOL_EDITOR_CONTROL::Save,                  ACTIONS::save.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::Save,                  EE_ACTIONS::saveLibraryAs.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::Save,                  EE_ACTIONS::saveSymbolAs.MakeEvent() );
@@ -551,6 +692,7 @@ void SYMBOL_EDITOR_CONTROL::setTransitions()
     Go( &SYMBOL_EDITOR_CONTROL::Revert,                ACTIONS::revert.MakeEvent() );
 
     Go( &SYMBOL_EDITOR_CONTROL::DuplicateSymbol,       EE_ACTIONS::duplicateSymbol.MakeEvent() );
+    Go( &SYMBOL_EDITOR_CONTROL::RenameSymbol,          EE_ACTIONS::renameSymbol.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::CutCopyDelete,         EE_ACTIONS::deleteSymbol.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::CutCopyDelete,         EE_ACTIONS::cutSymbol.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::CutCopyDelete,         EE_ACTIONS::copySymbol.MakeEvent() );
@@ -564,6 +706,7 @@ void SYMBOL_EDITOR_CONTROL::setTransitions()
     Go( &SYMBOL_EDITOR_CONTROL::OnDeMorgan,            EE_ACTIONS::showDeMorganAlternate.MakeEvent() );
 
     Go( &SYMBOL_EDITOR_CONTROL::ShowElectricalTypes,   EE_ACTIONS::showElectricalTypes.MakeEvent() );
+    Go( &SYMBOL_EDITOR_CONTROL::ShowPinNumbers,        EE_ACTIONS::showPinNumbers.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::PinLibrary,            ACTIONS::pinLibrary.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::UnpinLibrary,          ACTIONS::unpinLibrary.MakeEvent() );
     Go( &SYMBOL_EDITOR_CONTROL::ToggleSymbolTree,      EE_ACTIONS::showSymbolTree.MakeEvent() );
