@@ -31,6 +31,7 @@
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <memory>
 #include <mutex>
+#include <shared_mutex>
 #include <project.h>
 #include <string_utf8_map.h>
 #include <richio.h>
@@ -329,7 +330,7 @@ public:
     /// Delete all rows.
     void Clear()
     {
-        std::lock_guard<std::mutex> lock( m_nickIndexMutex );
+        std::lock_guard<std::shared_mutex> lock( m_nickIndexMutex );
 
         m_rows.clear();
         m_nickIndex.clear();
@@ -454,7 +455,7 @@ public:
             if( *iter == *aRow )
             {
                 m_rows.erase( iter, iter + 1 );
-                reindex();
+                reindex( true );
                 return true;
             }
         }
@@ -539,9 +540,21 @@ protected:
      */
     bool migrate();
 
-    void reindex()
+    /**
+     * Rebuilds the m_nickIndex
+     *
+     * @param aForce is to avoid rebuilding the index multiple times because multiple threads hit ensureIndex
+     * at the same time
+     */
+    void reindex( bool aForce )
     {
-        std::lock_guard<std::mutex> lock( m_nickIndexMutex );
+        std::lock_guard<std::shared_mutex> lock( m_nickIndexMutex );
+
+        if( !aForce )
+        {
+            if( m_nickIndex.size() )
+                return;
+        }
 
         m_nickIndex.clear();
 
@@ -555,7 +568,7 @@ protected:
         // Lazy indexing may be required.  To handle lazy indexing, we must enforce
         // that "nickIndex" is either empty or accurate, but never inaccurate.
         if( !m_nickIndex.size() )
-            reindex();
+            reindex( false );
     }
 
 private:
@@ -580,7 +593,7 @@ protected:
     mutable int m_version;
 
     /// Mutex to protect access to the nickIndex variable
-    mutable std::mutex m_nickIndexMutex;
+    mutable std::shared_mutex m_nickIndexMutex;
 };
 
 #endif  // _LIB_TABLE_BASE_H_
