@@ -303,6 +303,13 @@ public:
     const wxString& GetSentryId();
 #endif
 
+    /**
+     * Determine if the application is running with a GUI
+     *
+     * @return true if there is a GUI and false otherwise
+     */
+    bool IsGUI();
+
     /**
      * wxWidgets on MSW tends to crash if you spool up more than one print job at a time.
      */
