@@ -1397,9 +1397,9 @@ private:
     void importPaths( Clipper2Lib::Paths64&               paths,
                      const std::vector<CLIPPER_Z_VALUE>& aZValueBuffer,
                      const std::vector<SHAPE_ARC>&       aArcBuffe );
-    void importPolyPath( Clipper2Lib::PolyPath64*        aPolyPath,
-                     const std::vector<CLIPPER_Z_VALUE>& aZValueBuffer,
-                     const std::vector<SHAPE_ARC>&       aArcBuffer );
+    void importPolyPath( const std::unique_ptr<Clipper2Lib::PolyPath64>& aPolyPath,
+                     const std::vector<CLIPPER_Z_VALUE>&                 aZValueBuffer,
+                     const std::vector<SHAPE_ARC>&                       aArcBuffer );
 
     void inflate1( int aAmount, int aCircleSegCount, CORNER_STRATEGY aCornerStrategy );
     void inflate2( int aAmount, int aCircleSegCount, CORNER_STRATEGY aCornerStrategy );
