@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019 CERN
- * Copyright (C) 2019-2022 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2023 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,6 +22,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
+#include <fmt/format.h>
+
 #include <tool/tool_manager.h>
 #include <tool/picker_tool.h>
 #include <drawing_sheet/ds_data_item.h>
@@ -131,7 +133,18 @@ int PL_EDIT_TOOL::Main( const TOOL_EVENT& aEvent )
     VECTOR2I    prevPos;
 
     if( !selection.Front()->IsNew() )
-        m_frame->SaveCopyInUndoList();
+    {
+        try
+        {
+            m_frame->SaveCopyInUndoList();
+        }
+        catch( const fmt::v9::format_error& exc )
+        {
+            wxLogWarning( wxS( "Exception \"%s\" serializing string ocurred." ),
+                          exc.what() );
+            return 1;
+        }
+    }
 
     // Main loop: keep receiving events
     do
