@@ -47,6 +47,7 @@
 #include <pcb_bitmap.h>
 #include <pcb_text.h>
 #include <pcb_textbox.h>
+#include <pcb_dimension.h>
 #include <pgm_base.h>
 #include <pcbnew_settings.h>
 #include <progress_reporter.h>
@@ -75,6 +76,7 @@ BOARD::BOARD() :
         m_timeStamp( 1 ),
         m_paper( PAGE_INFO::A4 ),
         m_project( nullptr ),
+        m_userUnits( EDA_UNITS::MILLIMETRES ),
         m_designSettings( new BOARD_DESIGN_SETTINGS( nullptr, "board.design_settings" ) ),
         m_NetInfo( this )
 {
@@ -260,6 +262,7 @@ void BOARD::IncrementTimeStamp()
         m_DRCMaxPhysicalClearance = 0;
         m_DRCZones.clear();
         m_DRCCopperZones.clear();
+        m_ZoneIsolatedIslandsMap.clear();
         m_CopperZoneRTreeCache.clear();
         m_CopperItemRTreeCache = std::make_unique<DRC_RTREE>();
     }
@@ -288,7 +291,8 @@ void BOARD::UpdateRatsnestExclusions()
     GetConnectivity()->RunOnUnconnectedEdges(
             [&]( CN_EDGE& aEdge )
             {
-                if( aEdge.GetSourceNode() && aEdge.GetTargetNode() )
+                if( aEdge.GetSourceNode() && aEdge.GetTargetNode()
+                    && !aEdge.GetSourceNode()->Dirty() && !aEdge.GetTargetNode()->Dirty() )
                 {
                     std::pair<KIID, KIID> ids = { aEdge.GetSourceNode()->Parent()->m_Uuid,
                                                   aEdge.GetTargetNode()->Parent()->m_Uuid };
@@ -975,6 +979,37 @@ wxString BOARD::GetItemDescription( UNITS_PROVIDER* aUnitsProvider ) const
 }
 
 
+void BOARD::UpdateUserUnits( BOARD_ITEM* aItem, KIGFX::VIEW* aView )
+{
+    INSPECTOR_FUNC inspector =
+            [&]( EDA_ITEM* descendant, void* aTestData )
+            {
+                PCB_DIMENSION_BASE* dimension = static_cast<PCB_DIMENSION_BASE*>( descendant );
+
+                if( dimension->GetUnitsMode() == DIM_UNITS_MODE::AUTOMATIC )
+                {
+                    dimension->UpdateUnits();
+
+                    if( aView )
+                        aView->Update( dimension );
+                }
+
+                return INSPECT_RESULT::CONTINUE;
+            };
+
+    aItem->Visit( inspector, nullptr, { PCB_DIM_ALIGNED_T,
+                                        PCB_DIM_LEADER_T,
+                                        PCB_DIM_ORTHOGONAL_T,
+                                        PCB_DIM_CENTER_T,
+                                        PCB_DIM_RADIAL_T,
+                                        PCB_FP_DIM_ALIGNED_T,
+                                        PCB_FP_DIM_LEADER_T,
+                                        PCB_FP_DIM_ORTHOGONAL_T,
+                                        PCB_FP_DIM_CENTER_T,
+                                        PCB_FP_DIM_RADIAL_T } );
+}
+
+
 void BOARD::DeleteMARKERs()
 {
     // the vector does not know how to delete the PCB_MARKER, it holds pointers
