@@ -60,6 +60,7 @@ class CONNECTIVITY_DATA;
 class COMPONENT;
 class PROJECT;
 class PROGRESS_REPORTER;
+struct ISOLATED_ISLANDS;
 
 // The default value for m_outlinesChainingEpsilon to convert a board outlines to polygons
 // It is the max dist between 2 end points to see them connected
@@ -641,6 +642,15 @@ public:
 
     wxString GetItemDescription( UNITS_PROVIDER* aUnitsProvider ) const override;
 
+    EDA_UNITS GetUserUnits()                                { return m_userUnits; }
+    void SetUserUnits( EDA_UNITS aUnits )                   { m_userUnits = aUnits; }
+
+    /**
+     * Update any references within aItem (or its descendants) to the user units.  Primarily
+     * for automatic-unit dimensions.
+     */
+    void UpdateUserUnits( BOARD_ITEM* aItem, KIGFX::VIEW* aView );
+
     /**
      * Extract the board outlines and build a closed polygon from lines, arcs and circle items
      * on edge cut layer.
@@ -1168,6 +1178,7 @@ public:
     int                   m_DRCMaxClearance;
     int                   m_DRCMaxPhysicalClearance;
     ZONE*                 m_SolderMask;
+    std::map<ZONE*, std::map<PCB_LAYER_ID, ISOLATED_ISLANDS>> m_ZoneIsolatedIslandsMap;
 
 private:
     // The default copy constructor & operator= are inadequate,
@@ -1216,6 +1227,7 @@ private:
     TITLE_BLOCK         m_titles;                   // text in lower right of screen and plots
     PCB_PLOT_PARAMS     m_plotOptions;
     PROJECT*            m_project;                  // project this board is a part of
+    EDA_UNITS           m_userUnits;
 
     /**
      * All of the board design settings are stored as a JSON object inside the project file.  The
