@@ -27,6 +27,7 @@
 #include <footprint.h>
 #include <pad.h>
 #include <pcb_track.h>
+#include <pcb_text.h>
 #include <zone.h>
 #include <geometry/seg.h>
 #include <drc/drc_engine.h>
@@ -158,6 +159,36 @@ void DRC_TEST_PROVIDER_SOLDER_MASK::addItemToRTrees( BOARD_ITEM* aItem )
             }
         }
     }
+    else if( aItem->Type() == PCB_TEXT_T )
+    {
+        for( PCB_LAYER_ID layer : { F_Mask, B_Mask } )
+        {
+            if( aItem->IsOnLayer( layer ) )
+            {
+                const PCB_TEXT* text = static_cast<const PCB_TEXT*>( aItem );
+
+                text->TransformTextToPolySet( *solderMask->GetFill( layer ), layer,
+                                              m_webWidth / 2, m_maxError, ERROR_OUTSIDE );
+
+                m_itemTree->Insert( aItem, layer, m_largestClearance );
+            }
+        }
+    }
+    else if( aItem->Type() == PCB_FP_TEXT_T )
+    {
+        for( PCB_LAYER_ID layer : { F_Mask, B_Mask } )
+        {
+            if( aItem->IsOnLayer( layer ) )
+            {
+                const FP_TEXT* text = static_cast<const FP_TEXT*>( aItem );
+
+                text->TransformTextToPolySet( *solderMask->GetFill( layer ), layer,
+                                              m_webWidth / 2, m_maxError, ERROR_OUTSIDE );
+
+                m_itemTree->Insert( aItem, layer, m_largestClearance );
+            }
+        }
+    }
     else
     {
         for( PCB_LAYER_ID layer : { F_Mask, B_Mask } )
@@ -259,28 +290,34 @@ void DRC_TEST_PROVIDER_SOLDER_MASK::testSilkToMaskClearance()
                     if( !item->IsOnLayer( layer ) )
                         continue;
 
+                    PCB_LAYER_ID   maskLayer = layer == F_SilkS ? F_Mask : B_Mask;
                     BOX2I          itemBBox = item->GetBoundingBox();
                     DRC_CONSTRAINT constraint = m_drcEngine->EvalRules( SILK_CLEARANCE_CONSTRAINT,
-                                                                        item, nullptr, layer );
+                                                                        item, nullptr, maskLayer );
                     int            clearance = constraint.GetValue().Min();
                     int            actual;
                     VECTOR2I       pos;
 
-                    if( constraint.GetSeverity() == RPT_SEVERITY_IGNORE || clearance <= 0 )
+                    if( constraint.GetSeverity() == RPT_SEVERITY_IGNORE || clearance < 0 )
                         return true;
 
                     std::shared_ptr<SHAPE> itemShape = item->GetEffectiveShape( layer );
 
-                    if( m_fullSolderMaskRTree->QueryColliding( itemBBox, itemShape.get(), layer,
+                    if( m_fullSolderMaskRTree->QueryColliding( itemBBox, itemShape.get(), maskLayer,
                                                                clearance, &actual, &pos ) )
                     {
                         auto drce = DRC_ITEM::Create( DRCE_SILK_CLEARANCE );
-                        wxString msg = formatMsg( _( "(%s clearance %s; actual %s)" ),
-                                                  constraint.GetName(),
-                                                  clearance,
-                                                  actual );
 
-                        drce->SetErrorMessage( drce->GetErrorText() + wxS( " " ) + msg );
+                        if( clearance > 0 )
+                        {
+                            wxString msg = formatMsg( _( "(%s clearance %s; actual %s)" ),
+                                                      constraint.GetName(),
+                                                      clearance,
+                                                      actual );
+
+                            drce->SetErrorMessage( drce->GetErrorText() + wxS( " " ) + msg );
+                        }
+
                         drce->SetItems( item );
                         drce->SetViolatingRule( constraint.GetParentRule() );
 
@@ -368,6 +405,15 @@ bool DRC_TEST_PROVIDER_SOLDER_MASK::checkMaskAperture( BOARD_ITEM* aMaskItem, BO
         return false;
     }
 
+    if( fp && ii->second.first->Type() == PCB_PAD_T && aTestItem->Type() == PCB_PAD_T )
+    {
+        PAD* alreadyEncounteredPad = static_cast<PAD*>( ii->second.first );
+        PAD* thisPad = static_cast<PAD*>( aTestItem );
+
+        if( alreadyEncounteredPad->SharesNetTieGroup( thisPad ) )
+            return false;
+    }
+
     *aCollidingItem = ii->second.first;
     return true;
 }
