@@ -115,12 +115,16 @@ EXPORTER_STEP::EXPORTER_STEP( BOARD* aBoard, const EXPORTER_STEP_PARAMS& aParams
     m_hasGridOrigin( false ),
     m_board( aBoard ),
     m_pcbModel( nullptr ),
-    m_pcbName(),
     m_minDistance( STEPEXPORT_MIN_DISTANCE ),
     m_boardThickness( DEFAULT_BOARD_THICKNESS )
 {
     m_solderMaskColor = COLOR4D( 0.08, 0.20, 0.14, 0.83 );
 
+    // Init m_pcbBaseName to the board short filename (no path, no ext)
+    // m_pcbName is used later to identify items in step file
+    wxFileName fn( aBoard->GetFileName() );
+    m_pcbBaseName = fn.GetName();
+
     m_resolver = std::make_unique<FILENAME_RESOLVER>();
     m_resolver->Set3DConfigDir( wxT( "" ) );
     // needed to add the project to the search stack
@@ -257,7 +261,7 @@ bool EXPORTER_STEP::composePCB()
     else
         origin = m_params.m_origin;
 
-    m_pcbModel = std::make_unique<STEP_PCB_MODEL>( m_pcbName );
+    m_pcbModel = std::make_unique<STEP_PCB_MODEL>( m_pcbBaseName );
 
     // TODO: Handle when top & bottom soldermask colours are different...
     m_pcbModel->SetBoardColor( m_solderMaskColor.r, m_solderMaskColor.g, m_solderMaskColor.b );
