@@ -1700,13 +1700,20 @@ void FOOTPRINT::SetPosition( const VECTOR2I& aPos )
         switch( item->Type() )
         {
         case PCB_FP_SHAPE_T:
-        case PCB_FP_TEXTBOX_T:
         {
             FP_SHAPE* shape = static_cast<FP_SHAPE*>( item );
             shape->SetDrawCoord();
             break;
         }
 
+        case PCB_FP_TEXTBOX_T:
+        {
+            FP_TEXTBOX* textb = static_cast<FP_TEXTBOX*>( item );
+            textb->SetDrawCoord();
+            textb->ClearRenderCache();
+            break;
+        }
+
         case PCB_FP_TEXT_T:
         {
             FP_TEXT* text = static_cast<FP_TEXT*>( item );
