@@ -211,6 +211,9 @@ void PCB_BASE_FRAME::SetBoard( BOARD* aBoard, PROGRESS_REPORTER* aReporter )
         delete m_pcb;
         m_pcb = aBoard;
 
+        if( GetBoard() )
+            GetBoard()->SetUserUnits( GetUserUnits() );
+
         if( GetBoard() && GetCanvas() )
         {
             RENDER_SETTINGS* rs = GetCanvas()->GetView()->GetPainter()->GetSettings();
@@ -246,47 +249,11 @@ void PCB_BASE_FRAME::AddFootprintToBoard( FOOTPRINT* aFootprint )
         // it might be stored in another orientation if the lib is an archive built from a board)
         aFootprint->SetOrientation( ANGLE_0 );
 
-        UpdateUserUnits( aFootprint );
+        GetBoard()->UpdateUserUnits( aFootprint, GetCanvas()->GetView() );
     }
 }
 
 
-void PCB_BASE_FRAME::UpdateUserUnits( BOARD_ITEM* aItem, bool* aSelectedItemsModified )
-{
-    EDA_UNITS    units = GetUserUnits();
-    KIGFX::VIEW* view  = GetCanvas()->GetView();
-
-    INSPECTOR_FUNC inspector =
-            [&]( EDA_ITEM* descendant, void* aTestData )
-            {
-                PCB_DIMENSION_BASE* dimension = static_cast<PCB_DIMENSION_BASE*>( descendant );
-
-                if( dimension->GetUnitsMode() == DIM_UNITS_MODE::AUTOMATIC )
-                {
-                    dimension->SetUnits( units );
-                    dimension->Update();
-
-                    if( aSelectedItemsModified && dimension->IsSelected() )
-                        *aSelectedItemsModified = true;
-
-                    view->Update( dimension );
-                }
-
-                return INSPECT_RESULT::CONTINUE;
-            };
-
-    aItem->Visit( inspector, nullptr, { PCB_DIM_ALIGNED_T,
-                                        PCB_DIM_LEADER_T,
-                                        PCB_DIM_ORTHOGONAL_T,
-                                        PCB_DIM_CENTER_T,
-                                        PCB_DIM_RADIAL_T,PCB_FP_DIM_ALIGNED_T,
-                                        PCB_FP_DIM_LEADER_T,
-                                        PCB_FP_DIM_ORTHOGONAL_T,
-                                        PCB_FP_DIM_CENTER_T,
-                                        PCB_FP_DIM_RADIAL_T } );
-}
-
-
 EDA_ITEM* PCB_BASE_FRAME::GetItem( const KIID& aId ) const
 {
     return GetBoard()->GetItem( aId );
@@ -891,6 +858,9 @@ void PCB_BASE_FRAME::unitsChangeRefresh()
 {
     EDA_DRAW_FRAME::unitsChangeRefresh();    // Update the status bar.
 
+    if( GetBoard() )
+        GetBoard()->SetUserUnits( GetUserUnits() );
+
     UpdateGridSelectBox();
 }
 
