@@ -568,6 +568,7 @@ void PCB_EDIT_FRAME::SetPageSettings( const PAGE_INFO& aPageSettings )
                                                                &m_pcb->GetProperties() );
 
     drawingSheet->SetSheetName( std::string( GetScreenDesc().mb_str() ) );
+    drawingSheet->SetSheetPath( std::string( GetFullScreenDesc().mb_str() ) );
 
     // A board is not like a schematic having a main page and sub sheets.
     // So for the drawing sheet, use only the first page option to display items
@@ -1101,7 +1102,7 @@ void PCB_EDIT_FRAME::doCloseWindow()
     }
 
     // Make sure local settings are persisted
-    SaveProjectSettings();
+    SaveProjectLocalSettings();
 
     // Do not show the layer manager during closing to avoid flicker
     // on some platforms (Windows) that generate useless redraw of items in
@@ -1137,6 +1138,12 @@ void PCB_EDIT_FRAME::ActivateGalCanvas()
 
 void PCB_EDIT_FRAME::ShowBoardSetupDialog( const wxString& aInitialPage )
 {
+    std::unique_lock<std::mutex> dialogLock( DIALOG_BOARD_SETUP::g_Mutex, std::try_to_lock );
+
+    // One DIALOG_BOARD_SETUP dialog at a time.
+    if( !dialogLock.owns_lock() )
+        return;
+
     // Make sure everything's up-to-date
     GetBoard()->BuildListOfNets();
 
@@ -1148,7 +1155,8 @@ void PCB_EDIT_FRAME::ShowBoardSetupDialog( const wxString& aInitialPage )
     if( dlg.ShowQuasiModal() == wxID_OK )
     {
         GetBoard()->SynchronizeNetsAndNetClasses( true );
-        SaveProjectSettings();
+        // We don't know if anything was modified, so err on the side of requiring a save
+        OnModify();
 
         Kiway().CommonSettingsChanged( false, true );
 
@@ -1506,7 +1514,7 @@ void PCB_EDIT_FRAME::SetLastPath( LAST_PATH_TYPE aType, const wxString& aLastPat
     if( relativeFileName.GetFullPath() != project.m_PcbLastPath[ aType ] )
     {
         project.m_PcbLastPath[ aType ] = relativeFileName.GetFullPath();
-        SaveProjectSettings();
+        OnModify();
     }
 }
 
@@ -2171,6 +2179,7 @@ void PCB_EDIT_FRAME::ExchangeFootprint( FOOTPRINT* aExisting, FOOTPRINT* aNew,
                      resetTextLayers, resetTextEffects, aUpdated );
 
     // Copy fields in accordance with the reset* flags
+
     for( BOARD_ITEM* item : aExisting->GraphicalItems() )
     {
         FP_TEXT* srcItem = dyn_cast<FP_TEXT*>( item );
@@ -2191,12 +2200,33 @@ void PCB_EDIT_FRAME::ExchangeFootprint( FOOTPRINT* aExisting, FOOTPRINT* aNew,
         }
     }
 
-    if( !resetFabricationAttrs )
-        aNew->SetAttributes( aExisting->GetAttributes() );
+    if( resetFabricationAttrs )
+    {
+        // We've replaced the existing footprint with the library one, so the fabrication attrs
+        // are already reset.
+        //
+        // We only have to do anything if resetFabricationAttrs is *not* set....
+    }
+    else
+    {
+        // Careful; allow-soldermask-bridges is in the m_attributes field but is not presented
+        // as a fabrication attribute in the GUI....
+        int libraryFlagsToKeep = aNew->GetAttributes() & FP_ALLOW_SOLDERMASK_BRIDGES;
+        int existingFlagsToKeep = aExisting->GetAttributes() & ~FP_ALLOW_SOLDERMASK_BRIDGES;
+        aNew->SetAttributes( existingFlagsToKeep | libraryFlagsToKeep );
+    }
 
-    // Copy 3D model settings in accordance with the reset* flag
-    if( !reset3DModels )
+    if( reset3DModels )
+    {
+        // We've replaced the existing footprint with the library one, so the 3D models are
+        // already reset.
+        //
+        // We only have to do anything if reset3DModels is *not* set....
+    }
+    else
+    {
         aNew->Models() = aExisting->Models();  // Linked list of 3D models.
+    }
 
     // Updating other parameters
     const_cast<KIID&>( aNew->m_Uuid ) = aExisting->m_Uuid;
