@@ -484,7 +484,7 @@ void BRDITEMS_PLOTTER::PlotDimension( const PCB_DIMENSION_BASE* aDim )
     // the white items are not seen on a white paper or screen
     m_plotter->SetColor( color != WHITE ? color : LIGHTGRAY);
 
-    PlotPcbText( &aDim->Text(), aDim->GetLayer(), false );
+    PlotPcbText( aDim, aDim->GetLayer(), false );
 
     for( const std::shared_ptr<SHAPE>& shape : aDim->GetShapes() )
     {
@@ -922,9 +922,7 @@ void BRDITEMS_PLOTTER::PlotFilledAreas( const ZONE* aZone, PCB_LAYER_ID aLayer,
 
     GBR_METADATA gbr_metadata;
 
-    bool isOnCopperLayer = aZone->IsOnCopperLayer();
-
-    if( isOnCopperLayer )
+    if( aZone->IsOnCopperLayer() )
     {
         gbr_metadata.SetNetName( aZone->GetNetname() );
         gbr_metadata.SetCopper( true );
