@@ -45,6 +45,7 @@
 #include <pcb_text.h>
 #include <pcb_textbox.h>
 #include <pcbnew_settings.h>
+#include <pgm_base.h>
 #include <plugins/kicad/pcb_plugin.h>
 #include <plugins/kicad/pcb_parser.h>
 #include <trace_helpers.h>
@@ -810,7 +811,7 @@ void PCB_PLUGIN::format( const PCB_DIMENSION_BASE* aDimension, int aNestLevel )
 
     if( !center )
     {
-        Format( &aDimension->Text(), aNestLevel + 1 );
+        format( static_cast<const PCB_TEXT*>( aDimension ), aNestLevel + 1 );
 
         m_out->Print( aNestLevel + 1, "(format (prefix %s) (suffix %s) (units %d) (units_format %d) (precision %d)",
                       m_out->Quotew( aDimension->GetPrefix() ).c_str(),
@@ -2576,7 +2577,9 @@ void PCB_PLUGIN::FootprintSave( const wxString& aLibraryPath, const FOOTPRINT* a
                                                       "Would you like to create it?"),
                                                       aLibraryPath );
 
-            if( !IsGUI() || wxMessageBox( msg, _( "Library Not Found"), wxYES_NO | wxICON_QUESTION ) != wxYES )
+            if( !Pgm().IsGUI()
+                || wxMessageBox( msg, _( "Library Not Found" ), wxYES_NO | wxICON_QUESTION )
+                           != wxYES )
                 return;
 
             // Save throws its own IO_ERROR on failure, so no need to recreate here
