@@ -2,7 +2,7 @@
  * KiRouter - a push-and-(sometimes-)shove PCB router
  *
  * Copyright (C) 2013-2016 CERN
- * Copyright (C) 2016-2022 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2016-2023 KiCad Developers, see AUTHORS.txt for contributors.
  * Author: Tomasz Wlostowski <tomasz.wlostowski@cern.ch>
  *
  * This program is free software: you can redistribute it and/or modify it
@@ -232,6 +232,8 @@ bool PNS_PCBNEW_RULE_RESOLVER::IsNetTieExclusion( const PNS::ITEM* aItem,
                                                   const VECTOR2I& aCollisionPos,
                                                   const PNS::ITEM* aCollidingItem )
 {
+    wxCHECK( aItem && aCollidingItem, false );
+
     std::shared_ptr<DRC_ENGINE> drcEngine = m_board->GetDesignSettings().m_DRCEngine;
     BOARD_ITEM*                 collidingItem = aCollidingItem->Parent();
 
@@ -246,7 +248,7 @@ bool PNS_PCBNEW_RULE_RESOLVER::IsNetTieExclusion( const PNS::ITEM* aItem,
         return true;
     }
 
-    if( drcEngine && collidingItem )
+    if( drcEngine )
     {
         return drcEngine->IsNetTieExclusion( aItem->Net(), ToLAYER_ID( aItem->Layer() ),
                                              aCollisionPos, collidingItem );
@@ -258,31 +260,9 @@ bool PNS_PCBNEW_RULE_RESOLVER::IsNetTieExclusion( const PNS::ITEM* aItem,
 
 bool isCopper( const PNS::ITEM* aItem )
 {
-    BOARD_ITEM* parent = aItem->Parent();
+    const BOARD_ITEM *parent = aItem->Parent();
 
-    if( parent && parent->Type() == PCB_PAD_T )
-    {
-        PAD* pad = static_cast<PAD*>( parent );
-
-        if( !pad->IsOnCopperLayer() )
-            return false;
-
-        if( pad->GetAttribute() != PAD_ATTRIB::NPTH )
-            return true;
-
-        // round NPTH with a hole size >= pad size are not on a copper layer
-        // All other NPTH are seen on copper layers
-        // This is a basic criteria, but probably enough for a NPTH
-        if( pad->GetShape() == PAD_SHAPE::CIRCLE )
-        {
-            if( pad->GetSize().x <= pad->GetDrillSize().x )
-                return false;
-        }
-
-        return true;
-    }
-
-    return true;
+    return !parent || parent->IsOnCopperLayer();
 }
 
 
