@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2004-2018 Jean-Pierre Charras, jp.charras at wanadoo.fr
  * Copyright (C) 2011 Wayne Stambaugh <stambaughw@verizon.net>
- * Copyright (C) 1992-2020 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2022 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,7 +38,8 @@ TRACKS_CLEANER::TRACKS_CLEANER( BOARD* aPcb, BOARD_COMMIT& aCommit ) :
         m_brd( aPcb ),
         m_commit( aCommit ),
         m_dryRun( true ),
-        m_itemsList( nullptr )
+        m_itemsList( nullptr ),
+        m_reporter( nullptr )
 {
 }
 
@@ -49,27 +50,110 @@ TRACKS_CLEANER::TRACKS_CLEANER( BOARD* aPcb, BOARD_COMMIT& aCommit ) :
  * - vias on pad
  * - null length segments
  */
-void TRACKS_CLEANER::CleanupBoard( bool aDryRun, std::vector<std::shared_ptr<CLEANUP_ITEM> >* aItemsList,
+void TRACKS_CLEANER::CleanupBoard( bool aDryRun,
+                                   std::vector<std::shared_ptr<CLEANUP_ITEM> >* aItemsList,
                                    bool aRemoveMisConnected, bool aCleanVias, bool aMergeSegments,
-                                   bool aDeleteUnconnected, bool aDeleteTracksinPad, bool aDeleteDanglingVias )
+                                   bool aDeleteUnconnected, bool aDeleteTracksinPad,
+                                   bool aDeleteDanglingVias, REPORTER* aReporter )
 {
+    m_reporter = aReporter;
     bool has_deleted = false;
 
     m_dryRun = aDryRun;
     m_itemsList = aItemsList;
 
-    cleanup( aCleanVias, aMergeSegments || aRemoveMisConnected, aMergeSegments, aMergeSegments );
+    if( m_reporter )
+    {
+        if( aDryRun )
+            m_reporter->Report( _( "Checking null tracks and vias..." ) );
+        else
+            m_reporter->Report( _( "Removing null tracks and vias..." ) );
+
+        wxSafeYield();      // Timeslice to update UI
+    }
+
+    bool removeNullSegments = aMergeSegments || aRemoveMisConnected;
+    cleanup( aCleanVias, removeNullSegments, aMergeSegments /* dup segments*/, aMergeSegments );
+
+    if( m_reporter )
+    {
+        if( aDryRun )
+            m_reporter->Report( _( "Checking redundant tracks..." ) );
+        else
+            m_reporter->Report( _( "Removing redundant tracks..." ) );
+
+        wxSafeYield();      // Timeslice to update UI
+    }
+
+    cleanup( false, false, true, aMergeSegments );
 
     if( aRemoveMisConnected )
+    {
+        if( m_reporter )
+        {
+            if( aDryRun )
+                m_reporter->Report( _( "Checking shorting tracks..." ) );
+            else
+                m_reporter->Report( _( "Removing shorting tracks..." ) );
+
+            wxSafeYield();      // Timeslice to update UI
+        }
+
         removeShortingTrackSegments();
+    }
 
     if( aDeleteTracksinPad )
-        deleteTracksInPads();
+    {
+        if( m_reporter )
+        {
+            if( aDryRun )
+                m_reporter->Report( _( "Checking tracks in pads..." ) );
+            else
+                m_reporter->Report( _( "Removing tracks in pads..." ) );
 
-    has_deleted = deleteDanglingTracks( aDeleteUnconnected, aDeleteDanglingVias );
+            wxSafeYield();      // Timeslice to update UI
+        }
+
+        deleteTracksInPads();
+    }
+
+    if( aDeleteUnconnected || aDeleteDanglingVias )
+    {
+        if( m_reporter )
+        {
+            if( aDryRun )
+            {
+                m_reporter->Report( _( "Checking dangling tracks and vias..." ) );
+            }
+            else
+            {
+                if( aDeleteUnconnected )
+                    m_reporter->Report( _( "Removing dangling tracks..." ) );
+
+                if( aDeleteDanglingVias )
+                    m_reporter->Report( _( "Removing dangling vias..." ) );
+            }
+
+            wxSafeYield();      // Timeslice to update UI
+        }
+
+        has_deleted = deleteDanglingTracks( aDeleteUnconnected, aDeleteDanglingVias );
+    }
 
     if( has_deleted && aMergeSegments )
+    {
+        if( m_reporter )
+        {
+            if( aDryRun )
+                m_reporter->Report( _( "Checking collinear tracks..." ) );
+            else
+                m_reporter->Report( _( "Merging collinear tracks..." ) );
+
+            wxSafeYield();      // Timeslice to update UI
+        }
+
         cleanup( false, false, false, true );
+    }
 }
 
 
@@ -131,22 +215,22 @@ bool TRACKS_CLEANER::testTrackEndpointIsNode( PCB_TRACK* aTrack, bool aTstStart
 {
     // A node is a point where more than 2 items are connected.
 
-    auto connectivity = m_brd->GetConnectivity();
-    auto items = connectivity->GetConnectivityAlgo()->ItemEntry( aTrack ).GetItems();
+    const std::list<CN_ITEM*>& items =
+                m_brd->GetConnectivity()->GetConnectivityAlgo()->ItemEntry( aTrack ).GetItems();
 
     if( items.empty() )
         return false;
 
-    auto citem = items.front();
+    CN_ITEM* citem = items.front();
 
     if( !citem->Valid() )
         return false;
 
-    auto anchors = citem->Anchors();
+    const std::vector<std::shared_ptr<CN_ANCHOR>>& anchors = citem->Anchors();
 
     VECTOR2I refpoint = aTstStart ? aTrack->GetStart() : aTrack->GetEnd();
 
-    for( const auto& anchor : anchors )
+    for( const std::shared_ptr<CN_ANCHOR>& anchor : anchors )
     {
         if( anchor->Pos() != refpoint )
             continue;
@@ -241,8 +325,8 @@ void TRACKS_CLEANER::deleteTracksInPads()
             if( pad->HitTest( track->GetStart() ) && pad->HitTest( track->GetEnd() ) )
             {
                 SHAPE_POLY_SET poly;
-                track->TransformShapeWithClearanceToPolygon( poly, track->GetLayer(), 0,
-                                                             ARC_HIGH_DEF, ERROR_INSIDE );
+                track->TransformShapeToPolygon( poly, track->GetLayer(), 0, ARC_HIGH_DEF,
+                                                ERROR_INSIDE );
 
                 poly.BooleanSubtract( *pad->GetEffectivePolygon(), SHAPE_POLY_SET::PM_FAST );
 
@@ -354,7 +438,7 @@ void TRACKS_CLEANER::cleanup( bool aDeleteDuplicateVias, bool aDeleteNullSegment
             }
         }
 
-        if( aDeleteDuplicateSegments && track->Type() == PCB_TRACE_T )
+        if( aDeleteDuplicateSegments && track->Type() == PCB_TRACE_T && !track->IsNull() )
         {
             rtree.QueryColliding( track, track->GetLayer(), track->GetLayer(),
                     // Filter:
@@ -362,7 +446,8 @@ void TRACKS_CLEANER::cleanup( bool aDeleteDuplicateVias, bool aDeleteNullSegment
                     {
                         return aItem->Type() == PCB_TRACE_T
                                   && !aItem->HasFlag( SKIP_STRUCT )
-                                  && !aItem->HasFlag( IS_DELETED );
+                                  && !aItem->HasFlag( IS_DELETED )
+                                  && !static_cast<PCB_TRACK*>( aItem )->IsNull();
                     },
                     // Visitor:
                     [&]( BOARD_ITEM* aItem ) -> bool
@@ -392,65 +477,76 @@ void TRACKS_CLEANER::cleanup( bool aDeleteDuplicateVias, bool aDeleteNullSegment
     if( !m_dryRun )
         removeItems( toRemove );
 
-    if( aMergeSegments )
-    {
-        bool merged;
-
-        do
-        {
-            merged = false;
-            m_brd->BuildConnectivity();
-
-            auto connectivity = m_brd->GetConnectivity()->GetConnectivityAlgo();
-
-            // Keep a duplicate deque to all deleting in the primary
-            std::deque<PCB_TRACK*> temp_segments( m_brd->Tracks() );
-
-            // merge collinear segments:
-            for( PCB_TRACK* segment : temp_segments )
+    auto mergeSegments =
+            [&]( std::shared_ptr<CN_CONNECTIVITY_ALGO> connectivity ) -> bool
             {
-                if( segment->Type() != PCB_TRACE_T )    // one can merge only track collinear segments, not vias.
-                    continue;
-
-                if( segment->HasFlag( IS_DELETED ) )  // already taken in account
-                    continue;
-
-                for( CN_ITEM* citem : connectivity->ItemEntry( segment ).GetItems() )
+                for( PCB_TRACK* segment : m_brd->Tracks() )
                 {
-                    // Do not merge an end which has different width tracks attached -- it's a
-                    // common use-case for necking-down a track between pads.
-                    std::vector<PCB_TRACK*> sameWidthCandidates;
-                    std::vector<PCB_TRACK*> differentWidthCandidates;
+                    // one can merge only collinear segments, not vias or arcs.
+                    if( segment->Type() != PCB_TRACE_T )
+                        continue;
 
-                    for( CN_ITEM* connected : citem->ConnectedItems() )
+                    if( segment->HasFlag( IS_DELETED ) )  // already taken into account
+                        continue;
+
+                    // for each end of the segment:
+                    for( CN_ITEM* citem : connectivity->ItemEntry( segment ).GetItems() )
                     {
-                        if( !connected->Valid() )
+                        // Do not merge an end which has different width tracks attached -- it's a
+                        // common use-case for necking-down a track between pads.
+                        std::vector<PCB_TRACK*> sameWidthCandidates;
+                        std::vector<PCB_TRACK*> differentWidthCandidates;
+
+                        for( CN_ITEM* connected : citem->ConnectedItems() )
+                        {
+                            if( !connected->Valid() )
+                                continue;
+
+                            BOARD_CONNECTED_ITEM* candidate = connected->Parent();
+
+                            if( candidate->Type() == PCB_TRACE_T
+                                    && !candidate->HasFlag( IS_DELETED ) )
+                            {
+                                PCB_TRACK* candidateSegment = static_cast<PCB_TRACK*>( candidate );
+
+                                if( candidateSegment->GetWidth() == segment->GetWidth() )
+                                {
+                                    sameWidthCandidates.push_back( candidateSegment );
+                                }
+                                else
+                                {
+                                    differentWidthCandidates.push_back( candidateSegment );
+                                    break;
+                                }
+                            }
+                        }
+
+                        if( !differentWidthCandidates.empty() )
                             continue;
 
-                        BOARD_CONNECTED_ITEM* candidateItem = connected->Parent();
-
-                        if( candidateItem->Type() == PCB_TRACE_T && !candidateItem->HasFlag( IS_DELETED ) )
-                        {
-                            PCB_TRACK* candidateSegment = static_cast<PCB_TRACK*>( candidateItem );
-
-                            if( candidateSegment->GetWidth() == segment->GetWidth() )
-                                sameWidthCandidates.push_back( candidateSegment );
-                            else
-                                differentWidthCandidates.push_back( candidateSegment );
-                        }
-                    }
-
-                    if( differentWidthCandidates.size() == 0 )
-                    {
                         for( PCB_TRACK* candidate : sameWidthCandidates )
                         {
-                            if( segment->ApproxCollinear( *candidate ) )
-                                merged |= mergeCollinearSegments( segment, candidate );
+                            if( segment->ApproxCollinear( *candidate )
+                                    && mergeCollinearSegments( segment, candidate ) )
+                            {
+                                return true;
+                            }
                         }
                     }
                 }
-            }
-        } while( merged );
+
+                return false;
+            };
+
+    if( aMergeSegments )
+    {
+        do
+        {
+            while( !m_brd->BuildConnectivity() )
+                wxSafeYield();
+
+            m_connectedItemsCache.clear();
+        } while( mergeSegments( m_brd->GetConnectivity()->GetConnectivityAlgo() ) );
     }
 
     for( PCB_TRACK* track : m_brd->Tracks() )
@@ -458,12 +554,80 @@ void TRACKS_CLEANER::cleanup( bool aDeleteDuplicateVias, bool aDeleteNullSegment
 }
 
 
+const std::vector<BOARD_CONNECTED_ITEM*>& TRACKS_CLEANER::getConnectedItems( PCB_TRACK* aTrack )
+{
+    const std::shared_ptr<CONNECTIVITY_DATA>& connectivity = m_brd->GetConnectivity();
+
+    if( m_connectedItemsCache.count( aTrack ) == 0 )
+    {
+        m_connectedItemsCache[ aTrack ] =
+                connectivity->GetConnectedItems( aTrack, { PCB_TRACE_T, PCB_ARC_T, PCB_VIA_T,
+                                                           PCB_PAD_T, PCB_ZONE_T } );
+    }
+
+    return m_connectedItemsCache[ aTrack ];
+}
+
+
 bool TRACKS_CLEANER::mergeCollinearSegments( PCB_TRACK* aSeg1, PCB_TRACK* aSeg2 )
 {
     if( aSeg1->IsLocked() || aSeg2->IsLocked() )
         return false;
 
-    auto connectivity = m_brd->GetConnectivity();
+    // Collect the unique points where the two tracks are connected to other items
+    std::set<VECTOR2I> pts;
+
+    auto collectPts =
+            [&]( BOARD_CONNECTED_ITEM* citem )
+            {
+                if( citem->Type() == PCB_TRACE_T || citem->Type() == PCB_ARC_T
+                        || citem->Type() == PCB_VIA_T )
+                {
+                    PCB_TRACK* track = static_cast<PCB_TRACK*>( citem );
+
+                    if( track->IsPointOnEnds( aSeg1->GetStart() ) )
+                        pts.emplace( aSeg1->GetStart() );
+
+                    if( track->IsPointOnEnds( aSeg1->GetEnd() ) )
+                        pts.emplace( aSeg1->GetEnd() );
+
+                    if( track->IsPointOnEnds( aSeg2->GetStart() ) )
+                        pts.emplace( aSeg2->GetStart() );
+
+                    if( track->IsPointOnEnds( aSeg2->GetEnd() ) )
+                        pts.emplace( aSeg2->GetEnd() );
+                }
+                else
+                {
+                    if( citem->HitTest( aSeg1->GetStart(), ( aSeg1->GetWidth() + 1 ) / 2 ) )
+                        pts.emplace( aSeg1->GetStart() );
+
+                    if( citem->HitTest( aSeg1->GetEnd(), ( aSeg1->GetWidth() + 1 ) / 2  ) )
+                        pts.emplace( aSeg1->GetEnd() );
+
+                    if( citem->HitTest( aSeg2->GetStart(), ( aSeg2->GetWidth() + 1 ) / 2  ) )
+                        pts.emplace( aSeg2->GetStart() );
+
+                    if( citem->HitTest( aSeg2->GetEnd(), ( aSeg2->GetWidth() + 1 ) / 2  ) )
+                        pts.emplace( aSeg2->GetEnd() );
+                }
+            };
+
+    for( BOARD_CONNECTED_ITEM* item : getConnectedItems( aSeg1 ) )
+    {
+        if( item != aSeg1 && item != aSeg2 )
+            collectPts( item );
+    }
+
+    for( BOARD_CONNECTED_ITEM* item : getConnectedItems( aSeg2 ) )
+    {
+        if( item != aSeg1 && item != aSeg2 )
+            collectPts( item );
+    }
+
+    // This means there is a node in the center
+    if( pts.size() > 2 )
+        return false;
 
     // Verify the removed point after merging is not a node.
     // If it is a node (i.e. if more than one other item is connected, the segments cannot be merged
@@ -482,18 +646,33 @@ bool TRACKS_CLEANER::mergeCollinearSegments( PCB_TRACK* aSeg1, PCB_TRACK* aSeg2
     if( ( aSeg1->GetStart().x > aSeg1->GetEnd().x )
             == ( aSeg1->GetStart().y > aSeg1->GetEnd().y ) )
     {
-        dummy_seg.SetStart( wxPoint( min_x, min_y ) );
-        dummy_seg.SetEnd( wxPoint( max_x, max_y ) );
+        dummy_seg.SetStart( VECTOR2I( min_x, min_y ) );
+        dummy_seg.SetEnd( VECTOR2I( max_x, max_y ) );
     }
     else
     {
-        dummy_seg.SetStart( wxPoint( min_x, max_y ) );
-        dummy_seg.SetEnd( wxPoint( max_x, min_y ) );
+        dummy_seg.SetStart( VECTOR2I( min_x, max_y ) );
+        dummy_seg.SetEnd( VECTOR2I( max_x, min_y ) );
+    }
+
+    // If the existing connected points are not the same as the points generated by our
+    // min/max alg, then assign the missing points to the end closest.  This ensures that
+    // our replacement track is still connected
+    for( auto& pt : pts )
+    {
+        if( !dummy_seg.IsPointOnEnds( wxPoint( pt.x, pt.y ) ) )
+        {
+            if( ( VECTOR2I( dummy_seg.GetStart() ) - pt ).SquaredEuclideanNorm() <
+                    ( VECTOR2I( dummy_seg.GetEnd() ) - pt ).SquaredEuclideanNorm() )
+                dummy_seg.SetStart( wxPoint( pt.x, pt.y ) );
+            else
+                dummy_seg.SetEnd( wxPoint( pt.x, pt.y ) );
+        }
     }
 
     // Now find the removed end(s) and stop merging if it is a node:
     if( aSeg1->GetStart() != dummy_seg.GetStart() && aSeg1->GetStart() != dummy_seg.GetEnd() )
-    {
+     {
         if( testTrackEndpointIsNode( aSeg1, true ) )
             return false;
     }
@@ -515,10 +694,10 @@ bool TRACKS_CLEANER::mergeCollinearSegments( PCB_TRACK* aSeg1, PCB_TRACK* aSeg2
         m_commit.Modify( aSeg1 );
         *aSeg1 = dummy_seg;
 
-        connectivity->Update( aSeg1 );
+        m_brd->GetConnectivity()->Update( aSeg1 );
 
         // Clear the status flags here after update.
-        for( auto pad : connectivity->GetConnectedPads( aSeg1 ) )
+        for( PAD* pad : m_brd->GetConnectivity()->GetConnectedPads( aSeg1 ) )
         {
             aSeg1->SetState( BEGIN_ONPAD, pad->HitTest( aSeg1->GetStart() ) );
             aSeg1->SetState( END_ONPAD, pad->HitTest( aSeg1->GetEnd() ) );
@@ -535,7 +714,7 @@ bool TRACKS_CLEANER::mergeCollinearSegments( PCB_TRACK* aSeg1, PCB_TRACK* aSeg2
 
 void TRACKS_CLEANER::removeItems( std::set<BOARD_ITEM*>& aItems )
 {
-    for( auto item : aItems )
+    for( BOARD_ITEM* item : aItems )
     {
         m_brd->Remove( item );
         m_commit.Removed( item );
