@@ -205,22 +205,19 @@ public:
     void OnBoardChanged();
 
     void OnBoardNetSettingsChanged( BOARD& aBoard ) override;
-
     void OnBoardItemAdded( BOARD& aBoard, BOARD_ITEM* aItem ) override;
-
     void OnBoardItemsAdded( BOARD& aBoard, std::vector<BOARD_ITEM*>& aItems ) override;
-
     void OnBoardItemRemoved( BOARD& aBoard, BOARD_ITEM* aItem ) override;
-
     void OnBoardItemsRemoved( BOARD& aBoard, std::vector<BOARD_ITEM*>& aItems ) override;
-
     void OnBoardItemChanged( BOARD& aBoard, BOARD_ITEM* aItem ) override;
-
     void OnBoardItemsChanged( BOARD& aBoard, std::vector<BOARD_ITEM*>& aItems ) override;
 
     ///< Update the colors on all the widgets from the new chosen color theme.
     void OnColorThemeChanged();
 
+    ///< Respond to change in OS's DarkMode
+    void OnDarkModeToggle();
+
     ///< Update the widget when the active board layer is changed.
     void OnLayerChanged();
 
@@ -228,13 +225,10 @@ public:
     void OnNetVisibilityChanged( int aNetCode, bool aVisibility );
 
     ///< Manually update visibility for a given layer
-    void SetLayerVisible( LAYER_NUM aLayer, bool isVisible );
+    void SetLayerVisible( int aLayer, bool isVisible );
 
     void SetObjectVisible( GAL_LAYER_ID aLayer, bool isVisible = true );
 
-    ///< Update the manual layer alpha overrides.
-    void OnLayerAlphaChanged();
-
     void UpdateDisplayOptions();
 
     ///< Return a list of the layer presets created by the user.
@@ -255,10 +249,19 @@ public:
             return wxEmptyString;
     }
 
-    const wxArrayString& GetLayerPresetsMRU()
-    {
-        return m_presetMRU;
-    }
+    const wxArrayString& GetLayerPresetsMRU() { return m_presetMRU; }
+
+    ///< Return a list of viewports created by the user.
+    std::vector<VIEWPORT> GetUserViewports() const;
+
+    ///< Update the current viewports from those saved in the project file.
+    void SetUserViewports( std::vector<VIEWPORT>& aPresetList );
+
+    void ApplyViewport( const wxString& aPresetName );
+
+    void ApplyViewport( const VIEWPORT& aPreset );
+
+    const wxArrayString& GetViewportsMRU() { return m_viewportMRU; }
 
     void OnColorSwatchChanged( wxCommandEvent& aEvent );
 
@@ -277,17 +280,11 @@ public:
 
 protected:
     void OnNotebookPageChanged( wxNotebookEvent& event ) override;
-
     void OnSetFocus( wxFocusEvent& aEvent ) override;
-
     void OnSize( wxSizeEvent& aEvent ) override;
-
     void OnNetGridClick( wxGridEvent& event ) override;
-
     void OnNetGridDoubleClick( wxGridEvent& event ) override;
-
     void OnNetGridRightClick( wxGridEvent& event ) override;
-
     void OnNetGridMouseEvent( wxMouseEvent& aEvent );
 
 private:
@@ -303,6 +300,8 @@ private:
 
     void syncObjectSettings();
 
+    void buildNetClassMenu( wxMenu& aMenu, bool isDefaultClass, const wxString& aName );
+
     void rebuildNets();
 
     void loadDefaultLayerPresets();
@@ -311,6 +310,8 @@ private:
 
     void syncLayerPresetSelection();
 
+    void rebuildViewportsWidget();
+
     void onLayerLeftClick( wxMouseEvent& aEvent );
 
     void rightClickHandler( wxMouseEvent& aEvent );
@@ -335,6 +336,12 @@ private:
 
     void doApplyLayerPreset( const LAYER_PRESET& aPreset );
 
+    void updateViewportSelection( const wxString& aName );
+
+    void onViewportChanged( wxCommandEvent& aEvent ) override;
+
+    void doApplyViewport( const VIEWPORT& aViewport );
+
     void onNetclassVisibilityChanged( wxCommandEvent& aEvent );
 
     void showNetclass( const wxString& aClassName, bool aShow = true );
@@ -384,30 +391,26 @@ private:
     wxGridCellCoords m_hoveredCell;
 
     std::vector<std::unique_ptr<APPEARANCE_SETTING>> m_layerSettings;
-
-    std::map<PCB_LAYER_ID, APPEARANCE_SETTING*> m_layerSettingsMap;
+    std::map<PCB_LAYER_ID, APPEARANCE_SETTING*>      m_layerSettingsMap;
 
     std::vector<std::unique_ptr<APPEARANCE_SETTING>> m_objectSettings;
-
-    std::map<GAL_LAYER_ID, APPEARANCE_SETTING*> m_objectSettingsMap;
+    std::map<GAL_LAYER_ID, APPEARANCE_SETTING*>      m_objectSettingsMap;
 
     std::vector<std::unique_ptr<APPEARANCE_SETTING>> m_netclassSettings;
-
-    std::map<wxString, APPEARANCE_SETTING*> m_netclassSettingsMap;
+    std::map<wxString, APPEARANCE_SETTING*>          m_netclassSettingsMap;
 
     // TODO(JE) Move preset storage to the PCB_CONTROL tool
 
-    // Storage for all layer presets
     std::map<wxString, LAYER_PRESET> m_layerPresets;
+    LAYER_PRESET*                    m_currentPreset;
+    LAYER_PRESET*                    m_lastSelectedUserPreset;
+    wxArrayString                    m_presetMRU;
 
-    LAYER_PRESET* m_currentPreset;
+    std::map<wxString, VIEWPORT>     m_viewports;
+    VIEWPORT*                        m_lastSelectedViewport;
+    wxArrayString                    m_viewportMRU;
 
-    /// The last user (non-read-only) preset selected by the user
-    LAYER_PRESET* m_lastSelectedUserPreset;
-
-    wxArrayString m_presetMRU;
-
-    wxMenu* m_layerContextMenu;
+    wxMenu*                          m_layerContextMenu;
 
     /// Stores wxIDs for each netclass for control event mapping
     std::map<int, wxString> m_netclassIdMap;
